@@ -73,6 +73,8 @@ static void register_panel_add_single_transaction(GtkWindow *window, Transaction
 
 static void register_panel_add_after_propagate(struct register_panel_data *data, Transaction *add_txn);
 
+static gint txn_list_get_count_reconciled(GtkTreeView *treeview);
+
 /* account action functions -------------------- */
 
 static void register_panel_action_editfilter(GtkMenuItem *menuitem, gpointer     user_data)
@@ -258,11 +260,13 @@ struct register_panel_data *data = user_data;
 GtkTreeModel *model;
 GtkTreeIter iter;
 GList *badxferlist;
-gboolean valid;
+gboolean valid, lockrecon;
 gint count;
 
 	DB( g_print("\n[register] check intenal xfer\n") );
 
+	lockrecon = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+
 	badxferlist = NULL;
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
@@ -274,6 +278,10 @@ gint count;
 			MODEL_TXN_POINTER, &txn,
 			-1);
 
+		//#1909749 skip reconciled if lock is ON
+		if( lockrecon && txn->status == TXN_STATUS_RECONCILED )
+			goto next;
+
 		if( txn->flags & OF_INTXFER )
 		{
 			if( transaction_xfer_child_strong_get(txn) == NULL )
@@ -296,7 +304,7 @@ gint count;
 				}
 			}
 		}
-		
+next:
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 	}
 
@@ -343,6 +351,32 @@ gint count;
 }
 
 
+//#1983995 copy raw amount
+static void register_panel_action_copyrawamount(GtkMenuItem *menuitem, gpointer     user_data)
+{
+struct register_panel_data *data = user_data;
+Transaction *ope;
+
+	ope = list_txn_get_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+	if(ope != NULL)
+	{
+	Currency *cur = da_cur_get(ope->kcur);
+
+		if( cur != NULL )
+		{
+		GtkClipboard *clipboard = gtk_clipboard_get_default(gdk_display_get_default());
+		gdouble monval = hb_amount_round(ABS(ope->amount), cur->frac_digits);
+		gchar *text;
+
+			text = g_strdup_printf ("%.*f", cur->frac_digits, monval);
+			DB( g_print(" raw amount is '%s'\n", text) );
+			gtk_clipboard_set_text(clipboard, text, strlen(text));
+			g_free(text);
+		}
+	}
+}
+
+
 static void register_panel_action_viewsplit(GtkMenuItem *menuitem, gpointer     user_data)
 {
 struct register_panel_data *data = user_data;
@@ -353,6 +387,7 @@ Transaction *ope;
 		ui_split_view_dialog(data->window, ope);
 }
 
+
 /* = = = = = = = = end future version = = = = = = = = */
 
 
@@ -393,7 +428,8 @@ gint result;
 			GTK_WINDOW(data->window),
 			_("Are you sure you want to convert this account\nto Euro as Major currency?"),
 			msg,
-			_("_Convert")
+			_("_Convert"),
+			FALSE
 		);
 
 	g_free(msg);
@@ -494,6 +530,7 @@ static void register_panel_action_assign(GtkMenuItem *menuitem, gpointer     use
 struct register_panel_data *data = user_data;
 gint count;
 gboolean usermode = TRUE;
+gboolean lockrecon;
 
 	// noaction if show all account
 	if(data->showall)
@@ -501,7 +538,9 @@ gboolean usermode = TRUE;
 
 	DB( g_print("action assign\n") );
 
-	count = transaction_auto_assign(g_queue_peek_head_link(data->acc->txn_queue), data->acc->key);
+	lockrecon = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+
+	count = transaction_auto_assign(g_queue_peek_head_link(data->acc->txn_queue), data->acc->key, lockrecon);
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_ope));
 	GLOBALS->changes_count += count;
 
@@ -654,7 +693,8 @@ gint result, count;
 				GTK_WINDOW(data->window),
 				NULL,
 				_("Do you want to create an assignment with\neach of the selected transaction?"),
-				_("_Create")
+				_("_Create"),
+				FALSE
 			);
 
 	/*
@@ -721,7 +761,8 @@ gint result, count;
 				GTK_WINDOW(data->window),
 				NULL,
 				_("Do you want to create a template with\neach of the selected transaction?"),
-				_("_Create")
+				_("_Create"),
+				FALSE
 			);
 
 	/*
@@ -860,9 +901,13 @@ struct register_panel_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	
-	DB( g_print("\n[register] changes is %d\n", state) );
+	DB( g_print(" changes is %d\n", state) );
 	
-	gtk_image_set_from_icon_name(GTK_IMAGE(data->IM_reconchange), state == TRUE ? ICONNAME_CHANGES_ALLOW : ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
+	gtk_image_set_from_icon_name(GTK_IMAGE(data->IM_lockreconciled), state == TRUE ? ICONNAME_CHANGES_PREVENT : ICONNAME_CHANGES_ALLOW, GTK_ICON_SIZE_BUTTON);
+
+	//5.6 add lockreconciled icon
+	list_txn_set_lockreconciled(GTK_TREE_VIEW(data->LV_ope), state);
+	gtk_widget_queue_draw (data->LV_ope);
 
 	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE));
 
@@ -1636,7 +1681,8 @@ gboolean result;
 					GTK_WINDOW(data->window),
 					NULL,
 					_("Do you want to delete\neach of the selected transaction?"),
-					_("_Delete")
+					_("_Delete"),
+					TRUE
 				);
 
 			if(result == GTK_RESPONSE_OK)
@@ -1718,7 +1764,8 @@ gboolean result;
 					GTK_WINDOW(data->window),
 					_("Are you sure you want to change the status to None?"),
 					_("Some transaction in your selection are already Reconciled."),
-					_("_Change")
+					_("_Change"),
+					FALSE
 				);
 			}
 			else
@@ -1776,7 +1823,8 @@ gboolean result;
 					GTK_WINDOW(data->window),
 					_("Are you sure you want to toggle the status Reconciled?"),
 					_("Some transaction in your selection are already Reconciled."),
-					_("_Toggle")
+					_("_Toggle"),
+					FALSE
 				);
 			}
 			else
@@ -1841,6 +1889,30 @@ struct register_panel_data *data;
 }
 
 
+static gboolean register_panel_cb_on_key_press(GtkWidget *source, GdkEventKey *event, gpointer user_data)
+{
+struct register_panel_data *data = user_data;
+
+	// On Control-f enable search entry
+	//already bind to menu Txn > Find ctrl+F
+	/*if (event->state & GDK_CONTROL_MASK
+		&& event->keyval == GDK_KEY_f)
+	{
+		gtk_widget_grab_focus(data->ST_search);
+	}
+	else*/
+	if (event->keyval == GDK_KEY_Escape && gtk_widget_has_focus(data->ST_search))
+	{
+		hbtk_entry_set_text(GTK_ENTRY(data->ST_search), NULL);
+		gtk_widget_grab_focus(data->LV_ope);
+		return TRUE;
+	}
+
+	return GDK_EVENT_PROPAGATE;
+}
+
+
+
 static void register_panel_selection(GtkTreeSelection *treeselection, gpointer user_data)
 {
 
@@ -1936,7 +2008,7 @@ gint count = 0;
 	/* update disabled things */
 	if(flags & FLG_REG_SENSITIVE)
 	{
-	gboolean reconchange, sensitive, psensitive, nsensitive;
+	gboolean lockreconciled, sensitive, psensitive, nsensitive;
 	GtkTreeModel *model;
 	gint sort_column_id;
 	GtkSortType order;
@@ -1964,15 +2036,16 @@ gint count = 0;
 		hb_widget_visible(data->MI_autoassign, visible);
 		
 		//1909749 lock/unlock reconciled
-		reconchange = FALSE;
+		lockreconciled = !gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
 		if( ope != NULL )
 		{
-			if( (ope->status != TXN_STATUS_RECONCILED) || (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == TRUE) )
-				reconchange = TRUE;
+			if( (ope->status != TXN_STATUS_RECONCILED) )
+				lockreconciled = TRUE;
 
-			DB( g_print(" - reconchange = %d (%d %d)\n", reconchange, ope->status != TXN_STATUS_RECONCILED, gtk_switch_get_state (GTK_SWITCH(data->SW_reconchange)) ) );
+			DB( g_print(" - lockreconciled = %d (%d %d)\n", lockreconciled, ope->status != TXN_STATUS_RECONCILED, gtk_switch_get_state (GTK_SWITCH(data->SW_lockreconciled)) ) );
 		}
 
+
 		//5.3.1 if closed account : disable any change
 		sensitive =  TRUE;
 		if( (data->showall == FALSE) && (data->acc->flags & AF_CLOSED) )
@@ -1988,10 +2061,11 @@ gint count = 0;
 		sensitive = (count != 1 ) ? FALSE : TRUE;
 		gtk_widget_set_sensitive(data->MI_herit, sensitive);
 		gtk_widget_set_sensitive(data->MI_popherit, sensitive);
-		gtk_widget_set_sensitive(data->MI_edit, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_popedit, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_edit, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_popedit, lockreconciled ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->BT_herit, sensitive);
-		gtk_widget_set_sensitive(data->BT_edit, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_edit, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_popcopyamount, sensitive);
 
 		//txn have split
 		sensitive = (count == 1) && (ope != NULL) && (ope->flags & OF_SPLIT) ? TRUE : FALSE;
@@ -2000,7 +2074,7 @@ gint count = 0;
 		// single: disable multiedit
 		sensitive = (count <= 1 ) ? FALSE : TRUE;
 		//1909749 lock/unlock reconciled
-		if( (txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope)) > 0) && (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == FALSE) )
+		if( (txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope)) > 0) && (gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) == TRUE) )
 			sensitive = FALSE;
 		gtk_widget_set_sensitive(data->MI_multiedit   , sensitive);
 		gtk_widget_set_sensitive(data->MI_popmultiedit, sensitive);
@@ -2009,17 +2083,17 @@ gint count = 0;
 		// no selection: disable reconcile, delete
 		sensitive = (count > 0 ) ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_copy, sensitive);
-		gtk_widget_set_sensitive(data->ME_menustatus, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->ME_popmenustatus, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_delete, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_popdelete, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->ME_menustatus, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->ME_popmenustatus, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_delete, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_popdelete, lockreconciled ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->MI_assign, sensitive);
 		gtk_widget_set_sensitive(data->MI_popassign, sensitive);
 		gtk_widget_set_sensitive(data->MI_template, sensitive);
 		gtk_widget_set_sensitive(data->MI_poptemplate, sensitive);
-		gtk_widget_set_sensitive(data->BT_delete, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->BT_clear, reconchange ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->BT_reconcile, reconchange ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_delete, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_clear, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_reconcile, lockreconciled ? sensitive : FALSE);
 		gtk_widget_set_sensitive(data->BT_template, sensitive);
 
 		//edit menu
@@ -2061,6 +2135,7 @@ gint count = 0;
 			}
 		}
 
+		hb_widget_visible(data->SP_updown, visible);
 		hb_widget_visible(data->BT_up, visible);
 		hb_widget_visible(data->BT_down, visible);
 		hb_widget_visible(data->MI_poptxnup, visible);
@@ -2159,17 +2234,24 @@ gint count = 0;
 	gtk_label_set_markup(GTK_LABEL(data->TX_selection), msg);
 	g_free (msg);
 
+	//update lock/unlock 
+	visible = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+	gtk_widget_set_tooltip_text (data->SW_lockreconciled, 
+		visible == TRUE ? _("Locked. Click to unlock") : _("Unlocked. Click to lock"));
+	
+	//gtk_label_set_label(GTK_LABEL(data->LB_lockreconciled), visible == TRUE ? _("Reconciled changes is permitted") : _("Change of reconciled is locked"));
+
 }
 
 
-void register_panel_onRowActivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer userdata)
+static void register_panel_onRowActivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer userdata)
 {
 struct register_panel_data *data;
 GtkTreeModel *model;
 GtkTreeIter iter;
 gint col_id, count;
 Transaction *ope;
-gboolean reconchange;
+gboolean lockreconciled;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -2190,11 +2272,11 @@ gboolean reconchange;
 	if( count == 1)
 	{
 		//1909749 lock/unlock reconciled	
-		reconchange = FALSE;
-		if( (ope->status != TXN_STATUS_RECONCILED) || (gtk_switch_get_active (GTK_SWITCH(data->SW_reconchange)) == TRUE) )
-			reconchange = TRUE;
+		lockreconciled = FALSE;
+		if( (ope->status == TXN_STATUS_RECONCILED) && (gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) == TRUE) )
+			lockreconciled = TRUE;
 
-		if( reconchange == TRUE )
+		if( lockreconciled == FALSE )
 		{
 			register_panel_action(GTK_WIDGET(treeview), GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
 		}
@@ -2447,6 +2529,8 @@ GtkWidget *menuitem;
 
 	menuitem = hbtk_menu_add_menuitem (menu, _("View _Split"));
 	data->MI_popviewsplit = menuitem;
+	menuitem = hbtk_menu_add_menuitem (menu, _("Copy raw amount"));
+	data->MI_popcopyamount = menuitem;
 	menuitem = hbtk_menu_add_menuitem (menu, _("Create template..."));
 	data->MI_poptemplate = menuitem;
 	menuitem = hbtk_menu_add_menuitem (menu, _("Create assignment..."));
@@ -2473,6 +2557,7 @@ GtkWidget *menuitem;
 	g_signal_connect (data->MI_popstatrecon , "activate", G_CALLBACK (register_panel_action_reconcile), (gpointer)data);
 
 	g_signal_connect (data->MI_popviewsplit , "activate", G_CALLBACK (register_panel_action_viewsplit), (gpointer)data);
+	g_signal_connect (data->MI_popcopyamount, "activate", G_CALLBACK (register_panel_action_copyrawamount), (gpointer)data);
 	g_signal_connect (data->MI_poptemplate  , "activate", G_CALLBACK (register_panel_action_createtemplate), (gpointer)data);
 	g_signal_connect (data->MI_popassign    , "activate", G_CALLBACK (register_panel_action_createassignment), (gpointer)data);
 	g_signal_connect (data->MI_popdelete    , "activate", G_CALLBACK (register_panel_action_delete), (gpointer)data);
@@ -2565,7 +2650,8 @@ GtkAccelGroup *accel_group = NULL;
 static GtkWidget *
 register_panel_toolbar_create(struct register_panel_data *data)
 {
-GtkWidget *toolbar, *button;
+GtkWidget *toolbar, *button, *hbox, *widget, *label;
+GtkToolItem *toolitem;
 
 	toolbar = gtk_toolbar_new();
 	
@@ -2587,11 +2673,35 @@ GtkWidget *toolbar, *button;
 	data->BT_template  = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_CONVERT, _("Create template"), _("Create template"));
 	data->BT_delete    = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_OPE_DELETE, _("Delete"),  _("Delete selected transaction(s)"));
 
-	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
+	toolitem = gtk_separator_tool_item_new();
+	data->SP_updown = GTK_WIDGET(toolitem);
+	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 
 	data->BT_up   = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_OPE_MOVUP, _("Up"), _("Move transaction up"));
 	data->BT_down = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_OPE_MOVDW, _("Down"), _("Move transaction down"));
 
+
+	//#1909749 lock/unlock reconciled
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	gtk_widget_set_margin_start (hbox, SPACING_LARGE);
+
+	label = gtk_label_new (_("Reconciled changes is"));
+	data->LB_lockreconciled = label;
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+	widget = gtk_image_new_from_icon_name (ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
+	data->IM_lockreconciled = widget;
+	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+
+	widget = gtk_switch_new();
+	data->SW_lockreconciled = widget;
+	gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
+	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), hbox);
+	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolitem), -1);
+
 	return toolbar;
 }
 
@@ -2603,7 +2713,7 @@ GtkWidget *register_panel_window_new(Account *acc)
 {
 struct register_panel_data *data;
 struct WinGeometry *wg;
-GtkWidget *window, *mainbox, *intbox, *menubar, *table, *sw, *bar, *hbox;
+GtkWidget *window, *mainbox, *intbox, *menubar, *table, *sw, *bar;
 GtkWidget *treeview, *label, *widget, *image;
 gint row;
 
@@ -2647,11 +2757,7 @@ gint row;
 	}
 
 	gtk_window_set_title (GTK_WINDOW (window), data->wintitle);
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_OPE_SHOW );
 
-	//#1965594
-	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
-	
 	// connect our dispose function
 	g_signal_connect (window, "delete-event",
 		G_CALLBACK (register_panel_dispose), (gpointer)data);
@@ -2659,6 +2765,8 @@ gint row;
 	// connect our dispose function
 	g_signal_connect (window, "destroy",
 		G_CALLBACK (register_panel_destroy), (gpointer)data);
+		
+	g_signal_connect (window, "key-press-event", G_CALLBACK (register_panel_cb_on_key_press), (gpointer)data);
 
 	// connect our dispose function
 	//g_signal_connect (window, "configure-event",
@@ -2704,21 +2812,6 @@ gint row;
 	gtk_box_pack_start (GTK_BOX (intbox), table, FALSE, FALSE, 0);
 
 	row = 0;
-	//#1909749 lock/unlock reconciled
-	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_grid_attach (GTK_GRID(table), hbox, row, 0, 1, 1);
-	
-	widget = gtk_image_new_from_icon_name (ICONNAME_CHANGES_PREVENT, GTK_ICON_SIZE_BUTTON);
-	data->IM_reconchange = widget;
-	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
-
-	widget = gtk_switch_new();
-	data->SW_reconchange = widget;
-	gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
-	gtk_widget_set_tooltip_text (widget, _("Lock/unlock reconciled transaction"));
-	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
-
-	row++;
 	label = make_label_widget(_("_Range:"));
 	gtk_grid_attach (GTK_GRID(table), label, row, 0, 1, 1);
 	row++;
@@ -2892,6 +2985,9 @@ gint row;
 	//TODO should move this
 	//setup
 	//TODO minor data seems no more used
+	gtk_switch_set_active(GTK_SWITCH(data->SW_lockreconciled), PREFS->lockreconciled);
+	list_txn_set_lockreconciled(GTK_TREE_VIEW(data->LV_ope), PREFS->lockreconciled);
+	
 	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope))), "minor", data->CM_minor);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_future), (PREFS->date_future_nbdays > 0) ? TRUE : FALSE );
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
@@ -2930,7 +3026,7 @@ gint row;
 	g_signal_connect (data->MI_filter    , "activate", G_CALLBACK (register_panel_action_editfilter), (gpointer)data);
 	g_signal_connect (data->MI_conveuro  , "activate", G_CALLBACK (register_panel_action_converttoeuro), (gpointer)data);
 
-	g_signal_connect (data->SW_reconchange, "state-set", G_CALLBACK (register_panel_cb_recon_change), NULL);
+	g_signal_connect (data->SW_lockreconciled, "state-set", G_CALLBACK (register_panel_cb_recon_change), NULL);
 
 	data->handler_id[HID_RANGE]	 = g_signal_connect (data->CY_range , "changed", G_CALLBACK (register_panel_cb_filter_daterange), NULL);
 	data->handler_id[HID_TYPE]	 = g_signal_connect (data->CY_type	, "changed", G_CALLBACK (register_panel_cb_filter_type), NULL);
@@ -2977,7 +3073,8 @@ gint row;
 	wg = &PREFS->acc_wg;
 	if(wg->s == 0)
 	{
-		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+		if( wg->l && wg->t )
+			gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
 		gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
 	}
 	else
@@ -2986,10 +3083,7 @@ gint row;
 	gtk_widget_show_all (window);
 	
 	gtk_widget_hide(data->IB_duplicate);
-	
-	/* make sure splash is up */
-	while (gtk_events_pending ())
-		gtk_main_iteration ();
+
 
 	return window;
 }
