@@ -79,9 +79,9 @@ struct register_panel_data
 	GtkWidget   *BT_add, *BT_herit, *BT_edit;
 	GtkWidget   *BT_clear, *BT_reconcile;
 	GtkWidget   *BT_multiedit, *BT_template, *BT_delete;
-	GtkWidget	*BT_up, *BT_down;
+	GtkWidget	*SP_updown, *BT_up, *BT_down;
+	GtkWidget	*SW_lockreconciled, *IM_lockreconciled, *LB_lockreconciled;
 
-	GtkWidget	*SW_reconchange, *IM_reconchange;
 	GtkWidget	*CY_range;
 	GtkWidget	*CM_future;
 	GtkWidget	*CY_type;
@@ -106,7 +106,7 @@ struct register_panel_data
 	GtkWidget	*MI_popadd, *MI_popherit, *MI_popedit;
 	GtkWidget	*MI_popstatnone, *MI_popstatclear, *MI_popstatrecon;
 	GtkWidget	*MI_popmultiedit, *MI_poptemplate, *MI_popassign, *MI_popdelete;
-	GtkWidget	*MI_popviewsplit, *MI_poptxnup, *MI_poptxndown;
+	GtkWidget	*MI_popcopyamount, *MI_popviewsplit, *MI_poptxnup, *MI_poptxndown;
 	
 
 	gint	busy;
