@@ -133,7 +133,8 @@ gint result;
 			GTK_WINDOW(GLOBALS->mainwindow),
 			title,
 			secondtext,
-			_("_Revert")
+			_("_Revert"),
+			TRUE
 		);
 
 	g_free(title);
@@ -331,7 +332,8 @@ gchar *secondtext;
 			GTK_WINDOW(GLOBALS->mainwindow),
 			title,
 			secondtext,
-			_("_Anonymize")
+			_("_Anonymize"),
+			TRUE
 		);
 
 	//#1707201
@@ -996,7 +998,8 @@ gboolean result;
 		GTK_WINDOW(GLOBALS->mainwindow),
 		_("Open the backup file?"),
 		secondtext,
-		_("_Open backup")
+		_("_Open backup"),
+		FALSE
 	);	
 
 	g_free(secondtext);
@@ -1214,7 +1217,8 @@ gint r = XML_UNSET;
 					GTK_WINDOW(GLOBALS->mainwindow),
 					_("The file has been modified since reading it."),
 					_("If you save it, all the external changes could be lost. Save it anyway?"),
-					_("S_ave Anyway")
+					_("S_ave Anyway"),
+					TRUE
 				);
 				
 			if( result != GTK_RESPONSE_OK )
