@@ -29,6 +29,7 @@ struct _pnlaccgrp
 	//gshort		type;
 	//gshort		pos;
 	//gboolean	expanded;
+	gboolean	showtotal;
 	gdouble		bal_clear;
 	gdouble		bal_recon;
 	gdouble		bal_today;
@@ -70,6 +71,7 @@ struct hbfile_data
 	GtkWidget   *BT_collapseall;
 	gboolean	showall;
 	GSimpleActionGroup *action_group_acc;
+	GSimpleActionGroup *action_group_top;
 	GHashTable  *h_accgrp;
 	PnlAccGrp	*totaccgrp;
 
@@ -87,7 +89,6 @@ struct hbfile_data
 	GtkWidget   *BT_sched_post;
 	GtkWidget   *BT_sched_editpost;
 	GtkWidget	*CY_sched_range;
-	GtkWidget   *RA_type;
 
 	GtkWidget	*stack;
 	// max is 2=HUB_TXN_TYPE_REMIND, so 3 elt
