@@ -474,11 +474,13 @@ void filter_preset_status_set(Filter *flt, gint status)
 	DB( g_print("\n[filter] preset status set\n") );
 	
 	/* any status */
-	flt->option[FLT_GRP_TYPE] = 0;
+	//#1991459 dont reset type
+	//flt->option[FLT_GRP_TYPE] = 0;
 	flt->option[FLT_GRP_STATUS] = 0;
 	flt->option[FLT_GRP_CATEGORY] = 0;
 
-	flt->type   = FLT_TYPE_ALL;
+	//#1991459 dont reset type
+	//flt->type   = FLT_TYPE_ALL;
 	flt->status = FLT_STATUS_ALL;
 	//#1602835 fautly set
 	//flt->forceadd = TRUE;
@@ -492,8 +494,9 @@ void filter_preset_status_set(Filter *flt, gint status)
 	switch( status )
 	{
 		case FLT_STATUS_UNCATEGORIZED:
-			flt->option[FLT_GRP_TYPE] = 2;
-			flt->type = FLT_TYPE_INTXFER;
+			//#1991459 dont reset type: here to hide xfer txn
+			//flt->option[FLT_GRP_TYPE] = 2;
+			//flt->type = FLT_TYPE_INTXFER;
 			flt->option[FLT_GRP_CATEGORY] = 1;
 			filter_status_cat_clear_except(flt, 0);
 			break;
