@@ -1487,7 +1487,7 @@ guint nbofxtxn = 0;
 	if( ictx->do_auto_assign == TRUE )
 	{
 		DB( g_print(" call auto assign\n") );
-		transaction_auto_assign(txnlist, 0);
+		transaction_auto_assign(txnlist, 0, FALSE);
 	}	
 
 	//check for ofx internal xfer
