@@ -41,8 +41,12 @@ static const double fac[9] = { 1, 10, 100, 1000, 10000, 100000, 1000000, 1000000
 
 double hb_amount_round(const double x, unsigned int digits)
 {
-	digits = MAX(digits, 8);
-    return floor((x * fac[digits]) + 0.5) / fac[digits];
+	//fixed 5.6 MIN, not MAX... + #1977796
+	digits = MIN(digits, 8);
+
+	//#1977796
+	//return floor((x * fac[digits]) + 0.5) / fac[digits];
+	return round((x * fac[digits])) / fac[digits];
 }
 
 
@@ -277,7 +281,6 @@ gdouble monval;
 		g_ascii_formatd(formatd_buf, outlen, cur->format, monval);
 		hb_str_formatd(outstr, outlen, formatd_buf, cur, TRUE);
 	}
-
 }
 
 
@@ -377,8 +380,6 @@ gchar *color = NULL;
 }
 
 
-
-
 /*
 ** String utility
 */
@@ -544,6 +545,50 @@ gchar *d = str;
 }
 
 
+#if( (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 68) )
+guint g_string_replace (GString     *string,
+                  const gchar *find,
+                  const gchar *replace,
+                  guint        limit)
+{
+  gsize f_len, r_len, pos;
+  gchar *cur, *next;
+  guint n = 0;
+
+  g_return_val_if_fail (string != NULL, 0);
+  g_return_val_if_fail (find != NULL, 0);
+  g_return_val_if_fail (replace != NULL, 0);
+
+  f_len = strlen (find);
+  r_len = strlen (replace);
+  cur = string->str;
+
+  while ((next = strstr (cur, find)) != NULL)
+    {
+      pos = next - string->str;
+      g_string_erase (string, pos, f_len);
+      g_string_insert (string, pos, replace);
+      cur = string->str + pos + r_len;
+      n++;
+      /* Only match the empty string once at any given position, to
+       * avoid infinite loops */
+      if (f_len == 0)
+        {
+          if (cur[0] == '\0')
+            break;
+          else
+            cur++;
+        }
+      if (n == limit)
+        break;
+    }
+
+  return n;
+}
+
+#endif
+
+
 gchar *hb_string_copy_jsonpair(gchar *dst, gchar *str)
 {
 
@@ -598,8 +643,7 @@ gchar *d = str;
 }*/
 
 
-
-gchar*
+gchar *
 hb_strdup_nobrackets (const gchar *str)
 {
   const gchar *s;
@@ -669,7 +713,8 @@ const gchar *p;
 	p = string;
 	while(*p)
 	{
-		if( g_ascii_isdigit(*p) || *p=='-' || *p=='.' || *p==',' )
+		//if( g_ascii_isdigit(*p) || *p=='-' || *p=='.' || *p==',' )
+		if( g_ascii_isdigit(*p) || *p=='-' || *p=='+' || *p=='.' || *p==',' )
 			*d++ = *p;
 		p++;
 	}
@@ -682,7 +727,8 @@ const gchar *p;
 	p = san_str;
 	while(*p)
 	{
-		if(*p=='-' || g_ascii_isdigit(*p) )
+		//if(*p=='-' || g_ascii_isdigit(*p) )
+		if( *p=='-' || *p=='+' || g_ascii_isdigit(*p) )
 			*d++ = *p;
 		else
 			if( *p==gdc )
