@@ -80,7 +80,7 @@ gboolean hb_string_has_leading_trailing(gchar *str);
 void hb_string_replace_char(gchar c, gchar *str);
 gchar *hb_string_copy_jsonpair(gchar *dst, gchar *str);
 void hb_string_inline(gchar *str);
-gchar* hb_strdup_nobrackets (const gchar *str);
+gchar *hb_strdup_nobrackets (const gchar *str);
 
 gchar *hb_sprint_date(gchar *outstr, guint32 julian);
 
@@ -95,5 +95,11 @@ void hb_print_date(guint32 jdate, gchar *label);
 
 void hex_dump(guchar *ptr, guint length);
 
+#if( (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 68) )
+guint g_string_replace (GString     *string,
+                  const gchar *find,
+                  const gchar *replace,
+                  guint        limit);
+#endif
 
 #endif
