@@ -182,6 +182,8 @@ gint i;
 	//#1918334 no reason to show void by default
 	PREFS->showvoid = FALSE;
 	PREFS->includeremind = FALSE;
+	//#1980562
+	PREFS->lockreconciled = TRUE;
 	//#1673048
 	PREFS->txn_memoacp = TRUE;
 	PREFS->txn_memoacp_days = 365;
@@ -496,7 +498,7 @@ GtkSettings *settings = gtk_settings_get_default();
 		pango_font_description_set_size(pfd, PREFS->gtk_fontsize*PANGO_SCALE);
 
 		newfn = pango_font_description_to_string(pfd);
-		DB( g_print(" font-name '%s' == '%s' %d\n", newfn, pango_font_description_get_family(fd), pango_font_description_get_size(fd)/PANGO_SCALE) );
+		DB( g_print(" font-name '%s' == '%s' %d\n", newfn, pango_font_description_get_family(pfd), pango_font_description_get_size(pfd)/PANGO_SCALE) );
 		g_object_set(settings, "gtk-font-name", newfn, NULL);
 		g_free(newfn);
 
@@ -641,6 +643,7 @@ GError *error = NULL;
 				homebank_pref_get_boolean(keyfile, group, "ShowRemind", &PREFS->showremind);
 				homebank_pref_get_boolean(keyfile, group, "ShowVoid", &PREFS->showvoid);
 				homebank_pref_get_boolean(keyfile, group, "IncludeRemind", &PREFS->includeremind);
+				homebank_pref_get_boolean(keyfile, group, "LockReconciled", &PREFS->lockreconciled);
 				homebank_pref_get_boolean(keyfile, group, "TxnMemoAcp", &PREFS->txn_memoacp);
 				homebank_pref_get_short  (keyfile, group, "TxnMemoAcpDays", &PREFS->txn_memoacp_days);
 				homebank_pref_get_short  (keyfile, group, "TxnXferDayGap", &PREFS->txn_xfer_daygap);
@@ -668,7 +671,7 @@ GError *error = NULL;
 					{
 						src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpe", &length, NULL);
 
-						DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
+						DB( g_print(" - length %d (max=%d)\n", (int)length, NUM_LST_DSPOPE) );
 
 						if( length == NUM_LST_DSPOPE )
 						{
@@ -725,7 +728,7 @@ GError *error = NULL;
 
 					src = g_key_file_get_integer_list(keyfile, group, "ColumnsOpeWidth", &length, NULL);
 
-					DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
+					DB( g_print(" - length %d (max=%d)\n", (int)length, NUM_LST_DSPOPE) );
 
 					if( length == NUM_LST_DSPOPE )
 					{
@@ -737,7 +740,7 @@ GError *error = NULL;
 					g_free(src);
 					
 				}
-			
+
 				homebank_pref_get_integer(keyfile, group, "OpeSortId", &PREFS->lst_ope_sort_id);
 				homebank_pref_get_integer(keyfile, group, "OpeSortOrder", &PREFS->lst_ope_sort_order);
 
@@ -791,7 +794,7 @@ GError *error = NULL;
 				gsize length;
 					src = g_key_file_get_integer_list(keyfile, group, "AccColumns", &length, NULL);
 
-					DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
+					DB( g_print(" - length %d (max=%d)\n", (int)length, NUM_LST_DSPOPE) );
 
 					if( length == NUM_LST_COL_DSPACC )
 					{
@@ -1033,10 +1036,12 @@ GError *error = NULL;
 		g_key_file_set_boolean (keyfile, group, "ShowRemind", PREFS->showremind);
 		g_key_file_set_boolean (keyfile, group, "ShowVoid", PREFS->showvoid);
 		g_key_file_set_boolean (keyfile, group, "IncludeRemind", PREFS->includeremind);
+		g_key_file_set_boolean (keyfile, group, "LockReconciled", PREFS->lockreconciled);
 		g_key_file_set_boolean (keyfile, group, "TxnMemoAcp", PREFS->txn_memoacp);
 		g_key_file_set_integer (keyfile, group, "TxnMemoAcpDays" , PREFS->txn_memoacp_days);
 		g_key_file_set_integer (keyfile, group, "TxnXferDayGap" , PREFS->txn_xfer_daygap);
 
+		//register colums
 		g_key_file_set_integer_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_LST_DSPOPE);
 		g_key_file_set_integer_list(keyfile, group, "ColumnsOpeWidth", PREFS->lst_ope_col_width, NUM_LST_DSPOPE);
 		g_key_file_set_integer     (keyfile, group, "OpeSortId" , PREFS->lst_ope_sort_id);
