@@ -98,13 +98,15 @@ struct Preferences
 	gboolean	vehicle_unit_isgal;		// true if unit is gallon, default Liter
 
 	//transactions
+	//-- register
 	gint		date_range_txn;
 	gint		date_future_nbdays;
 	gboolean	hidereconciled;
 	gboolean    showremind;
 	gboolean    showvoid;
 	gboolean	includeremind;
-
+	gboolean	lockreconciled;
+	//-- dialog
 	gboolean	heritdate;
 	gboolean	txn_memoacp;
 	gshort		txn_xfer_daygap;
@@ -154,7 +156,10 @@ struct Preferences
 	gboolean	dtex_doautoassign;
 
 	gchar	    IntCurrSymbol[8];
+
 	gint 		lst_impope_columns[NUM_LST_DSPOPE+1];
+
+	//register list column
 	gint 		lst_ope_columns[NUM_LST_DSPOPE+1];
 	gint 		lst_ope_col_width[NUM_LST_DSPOPE+1];
 	gint		lst_ope_sort_id;	// -- implicit --
