@@ -625,8 +625,8 @@ gboolean retval = FALSE;
 	if(stxn == dtxn)
 		return FALSE;
 
-	DB( g_print(" src: %d %d %d %f %d\n", stxn->kcur, stxn->date, stxn->kacc, ABS(stxn->amount), stxn->kxfer ) );
-	DB( g_print(" dst: %d %d %d %f %d\n", dtxn->kcur, dtxn->date, dtxn->kacc, ABS(dtxn->amount), dtxn->kxfer ) );
+	DB( g_print(" src: %d %d %d %f %d\n", stxn->kcur, stxn->date, stxn->kacc, stxn->amount, stxn->kxfer ) );
+	DB( g_print(" dst: %d %d %d %f %d\n", dtxn->kcur, dtxn->date, dtxn->kacc, dtxn->amount, dtxn->kxfer ) );
 
 	if( stxn->kcur == dtxn->kcur &&
 	    //stxn->date == dtxn->date &&
@@ -635,10 +635,11 @@ gboolean retval = FALSE;
 	    (dtxn->date >= (stxn->date - daygap)) &&
 	    //v5.1 make no sense: stxn->kxferacc == dtxn->kacc &&
 	    stxn->kacc != dtxn->kacc &&
-	    ABS(stxn->amount) == ABS(dtxn->amount) &&
+	    //#1987975 only suggest opposite sign amount txn
+		stxn->amount == -dtxn->amount &&
+		//ABS(stxn->amount) == ABS(dtxn->amount) &&
 	    dtxn->kxfer == 0)
 	{
-		//TODO: we could evaluate here a match rate based on several fields
 		retval = TRUE;
 	}
 
@@ -675,6 +676,7 @@ GList *list, *matchlist = NULL;
 		
 				if( transaction_xfer_child_might(ope, item, PREFS->txn_xfer_daygap) == TRUE )
 				{
+					// evaluate here a match rate based on several fields
 					item->matchrate = transaction_xfer_child_match_rate(ope, item);
 					DB( g_print(" - match %3d: %d %s %f %d=>%d\n", item->matchrate, item->date, item->memo, item->amount, item->kacc, item->kxferacc) );
 					matchlist = g_list_append(matchlist, item);
@@ -703,47 +705,34 @@ gint count;
 
 	DB( g_print(" - found %d might match, switching\n", count) );
 
-	switch(count)
+	if( count == 0 )
 	{
-		case 0:		//we should create the child
-			transaction_xfer_create_child(ope);
-			break;
+		//we should create the child
+		transaction_xfer_create_child(ope);
+	}
+	//the user must choose himself
+	else
+	{
+	gint result;
+	Transaction *child = NULL;
 
-		//todo: maybe with just 1 match the user must choose ?
-		//#942346: bad idea so to no let the user confirm, so let him confirm
-		/*
-		case 1:		//transform the transaction to a child transfer
+		result = ui_dialog_transaction_xfer_select_child(parent, ope, matchlist, &child);
+		switch( result )
 		{
-			GList *list = g_list_first(matchlist);
-			transaction_xfer_change_to_child(ope, list->data);
-			break;
-		}
-		*/
-
-		default:	//the user must choose himself
-		{
-		gint result;
-		Transaction *child;
-
-			result = ui_dialog_transaction_xfer_select_child(parent, ope, matchlist, &child);
-			if( result == GTK_RESPONSE_ACCEPT )
-			{
-				//#1827193 child can be null...
+			case HB_RESPONSE_SELECTION:
+				//#1827193 in case child is null...
 				DB( g_print(" child %p\n", child) );
 				if( child != NULL )
 					transaction_xfer_change_to_child(ope, child);
-				else
-					transaction_xfer_create_child(ope);
-			}
-			else //GTK_RESPONSE_CANCEL
-			{
-				ope->paymode = PAYMODE_NONE;
-				ope->kxfer = 0;
-				ope->kxferacc = 0;
-				//fixed 5.5 when cancel xfer remains
-				ope->flags &= ~(OF_INTXFER);
-				da_transaction_set_flag(ope);
-			}
+				break;
+			case HB_RESPONSE_CREATE_NEW:
+				transaction_xfer_create_child(ope);
+				break;
+			default:
+				DB( g_print(" add normal txn\n") );
+				transaction_xfer_change_to_normal(ope);
+				da_transaction_set_flag(ope);				
+				break;			
 		}
 	}
 
@@ -787,6 +776,19 @@ GList *list;
 }
 
 
+void transaction_xfer_change_to_normal(Transaction *ope)
+{
+
+	DB( g_print("\n[transaction] xfer_change_to_normal\n") );
+
+	//remove xfer flags
+	ope->flags &= ~(OF_INTXFER);
+
+	ope->kxfer = 0;
+	ope->kxferacc = 0;
+
+}
+
 
 //TODO: should be static but used in hb_import
 void transaction_xfer_change_to_child(Transaction *ope, Transaction *child)
@@ -795,6 +797,7 @@ Account *dstacc;
 
 	DB( g_print("\n[transaction] xfer_change_to_child\n") );
 
+	//disable for != currencies
 	if(ope->kcur != child->kcur)
 		return;
 
@@ -1043,7 +1046,9 @@ Account *acc;
 
 	//controls accounts valid (archive scheduled maybe bad)
 	acc = da_acc_get(ope->kacc);
-	if(acc == NULL) return NULL;
+	//#1972078 forbid on a closed account
+	if( (acc == NULL) || (acc->flags & AF_CLOSED) )
+		return NULL;
 
 	DB( g_print(" acc is '%s' %d\n", acc->name, acc->key) );
 
@@ -1052,7 +1057,9 @@ Account *acc;
 	if(ope->flags & OF_INTXFER)
 	{
 		acc = da_acc_get(ope->kxferacc);
-		if(acc == NULL) return NULL;
+		//#1972078 forbid on a closed account
+		if( (acc == NULL) || (acc->flags & AF_CLOSED) ) 
+			return NULL;
 		
 		// delete any splits
 		da_split_destroy(ope->splits);
