@@ -45,18 +45,16 @@ extern struct Preferences *PREFS;
 /* This is not pretty. Of course you can also use a
    *  separate compare function for each sort ID value */
 
-static gint list_txn_sort_iter_compare_strings(gchar *s1, gchar *s2)
+static gint
+list_txn_sort_iter_compare_strings(gchar *s1, gchar *s2)
 {
 	return hb_string_utf8_compare(s1, s2);
 }
 
 
-static   gint
-  list_txn_sort_iter_compare_func (GtkTreeModel *model,
-                          GtkTreeIter  *a,
-                          GtkTreeIter  *b,
-                          gpointer      userdata)
-  {
+static gint
+list_txn_sort_iter_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
+{
     gint sortcol = GPOINTER_TO_INT(userdata);
     gint retval = 0;
 	Transaction *ope1, *ope2;
@@ -176,6 +174,17 @@ static   gint
 		}
 		break;
 
+		case LST_DSPOPE_MATCH:
+		{
+			tmpval = ope1->matchrate - ope2->matchrate;
+			retval = tmpval > 0 ? 1 : -1;
+			if(!retval)
+			{
+				retval = ope1->date - ope2->date;
+			}
+		}
+		break;
+		
 		default:
 			g_return_val_if_reached(0);
     }
@@ -184,7 +193,8 @@ static   gint
 }
 
 
-static void list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
+static void
+list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
 {
 	if(txn->date > GLOBALS->today)
 	{
@@ -231,21 +241,16 @@ static void list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
 		g_object_set(renderer, "weight-set", FALSE,
 		NULL);
 	}
-
-
-	
 }
 
 
-/*
-** date cell function
-*/
-static void list_txn_status_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_status_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Transaction *txn;
+Transaction *ope;
 gchar *iconname = NULL;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &txn, -1);
+	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
 
 	/*
 		stat[0] = ( entry->ope_Flags & OF_ADDED  ) ? data->istatus[2] : data->istatus[0];
@@ -257,14 +262,14 @@ gchar *iconname = NULL;
 	switch(GPOINTER_TO_INT(user_data))
 	{
 		case 1:
-			iconname = ( txn->flags & OF_AUTO  ) ? ICONNAME_HB_OPE_AUTO : ( txn->flags & OF_ADDED ) ? ICONNAME_HB_OPE_NEW : NULL;
+			iconname = ( ope->flags & OF_AUTO  ) ? ICONNAME_HB_OPE_AUTO : ( ope->flags & OF_ADDED ) ? ICONNAME_HB_OPE_NEW : NULL;
 			break;
 		case 2:
-			iconname = ( txn->flags & OF_CHANGED  ) ? ICONNAME_HB_OPE_EDIT : NULL;
+			iconname = ( ope->flags & OF_CHANGED  ) ? ICONNAME_HB_OPE_EDIT : NULL;
 			break;
 		case 3:
-			//iconname = ( txn->marker == TXN_MARK_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
-			iconname = ( txn->dspflags & TXN_DSPFLG_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
+			//iconname = ( ope->marker == TXN_MARK_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
+			iconname = ( ope->dspflags & TXN_DSPFLG_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
 			break;
 		/*case 3:
 			if( entry->flags & OF_VALID )
@@ -276,14 +281,13 @@ gchar *iconname = NULL;
 			}
 			break;*/
 	}
+
 	g_object_set(renderer, "icon-name", iconname, NULL);
 }
 
 
-/*
-** account cell function
-*/
-static void list_txn_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 Account *acc;
@@ -300,10 +304,8 @@ Account *acc;
 }
 
 
-/*
-** match rate cell function
-*/
-static void list_txn_match_rate_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_match_rate_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 gchar buffer[8];
@@ -315,10 +317,8 @@ gchar buffer[8];
 }
 
 
-/*
-** date cell function
-*/
-static void list_txn_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 gchar buffer[256];
@@ -333,20 +333,19 @@ GDate date;
 		g_date_strftime (buffer, 256-1, PREFS->date_format, &date);
 		#if MYDEBUG
 		gchar *ds = g_strdup_printf ("%s [%02d]", buffer, ope->pos );
-    	g_object_set(renderer, "text", ds, NULL);
+		g_object_set(renderer, "text", ds, NULL);
 		g_free(ds);
 		#else
-    	g_object_set(renderer, "text", buffer, NULL);
+		g_object_set(renderer, "text", buffer, NULL);
 		#endif
 	}
-    else
-    	g_object_set(renderer, "text", "????", NULL);
+	else
+		g_object_set(renderer, "text", "????", NULL);
 }
 
-/*
-** info cell function
-*/
-static void list_txn_info_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+
+static void 
+list_txn_info_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 
@@ -368,7 +367,8 @@ Transaction *ope;
 }
 
 
-static void list_txn_payeexfer_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_payeexfer_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 gchar *direction = "";
@@ -384,10 +384,8 @@ gchar *direction = "";
 }
 
 
-/*
-** payee cell function
-*/
-static void list_txn_payee_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_payee_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 
@@ -410,10 +408,8 @@ Transaction *ope;
 }
 
 
-/*
-** tags cell function
-*/
-static void list_txn_tags_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_tags_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 gchar *str;
@@ -429,22 +425,19 @@ gchar *str;
 	}
 	else
 		g_object_set(renderer, "text", "", NULL);
-
-
 }
 
 
-/*
-** memo cell function
-*/
-static void list_txn_memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+
+static void 
+list_txn_memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 
 	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
 	list_txn_eval_future(renderer, ope);
-	
-    g_object_set(renderer, "text", ope->memo, NULL);
+
+	g_object_set(renderer, "text", ope->memo, NULL);
 }
 
 
@@ -466,38 +459,50 @@ gchar *iconname = NULL;
 }
 
 
-/*
-** clr cell function
-*/
 static void 
 list_txn_clr_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
+struct list_txn_data *data = NULL;
+GtkWidget *widget;
 Transaction *ope;
 gchar *iconname = NULL;
 //const gchar *c = "";
-	
+
+	widget = gtk_tree_view_column_get_tree_view(col);
+	if( widget )
+		data = g_object_get_data(G_OBJECT(widget), "inst_data");
+
 	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	switch(ope->status)
+
+	switch(GPOINTER_TO_INT(user_data))
 	{
-		/*case TXN_STATUS_CLEARED: c = "c"; break;
-		case TXN_STATUS_RECONCILED: c = "R"; break;
-		case TXN_STATUS_REMIND: c = "!"; break;*/
-		case TXN_STATUS_CLEARED:	iconname = ICONNAME_HB_OPE_CLEARED; break;
-		case TXN_STATUS_RECONCILED: iconname = ICONNAME_HB_OPE_RECONCILED; break;
-		case TXN_STATUS_REMIND:     iconname = ICONNAME_HB_OPE_REMIND; break;
-		case TXN_STATUS_VOID:     iconname = ICONNAME_HB_OPE_VOID; break;		
+		case 1:
+			if( (data->lockreconciled == TRUE) && (ope->status == TXN_STATUS_RECONCILED) )
+				iconname = ICONNAME_CHANGES_PREVENT;
+			break;
+
+		case 2:
+		{
+			switch(ope->status)
+			{
+				/*case TXN_STATUS_CLEARED: c = "c"; break;
+				case TXN_STATUS_RECONCILED: c = "R"; break;
+				case TXN_STATUS_REMIND: c = "!"; break;*/
+				case TXN_STATUS_CLEARED:	iconname = ICONNAME_HB_OPE_CLEARED; break;
+				case TXN_STATUS_RECONCILED: iconname = ICONNAME_HB_OPE_RECONCILED; break;
+				case TXN_STATUS_REMIND:     iconname = ICONNAME_HB_OPE_REMIND; break;
+				case TXN_STATUS_VOID:     iconname = ICONNAME_HB_OPE_VOID; break;		
+			}
+		}
 	}
 
 	//g_object_set(renderer, "text", c, NULL);
 	g_object_set(renderer, "icon-name", iconname, NULL);
-	
 }
 
 
-/*
-** amount cell function
-*/
-static void list_txn_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 struct list_txn_data *data = NULL;
 GtkWidget *widget;
@@ -557,21 +562,19 @@ gchar *color;
 		g_object_set(renderer, "weight", PANGO_WEIGHT_BOLD, NULL);
 	else
 		g_object_set(renderer, "weight", PANGO_WEIGHT_NORMAL, NULL);
-
 	
 }
 
 
-/*
-** category cell function
-*/
-static void list_txn_category_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void 
+list_txn_category_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 struct list_txn_data *data = NULL;
 GtkWidget *widget;
 Transaction *ope;
 Category *cat;
-gchar *color, *text;
+gchar *color = NULL;
+gchar *text = NULL;
 
 	widget = gtk_tree_view_column_get_tree_view(col);
 	if( widget )
@@ -617,6 +620,46 @@ gchar *color, *text;
 /* = = = = = = = = = = = = = = = = */
 
 
+//#1967708 encode csv string: add string delimiter ", and doubled if inside
+static void list_txn_to_string_csv_text(GString *node, gchar *sep, gchar *text)
+{
+	if( text == NULL )
+	{
+		g_string_append (node, "");
+	}
+	else
+	{
+		//sep into string ?
+		if( g_strstr_len(text, -1, sep) == NULL )
+		{
+			//no: put native text
+			g_string_append (node, text);
+		}
+		else
+		{
+			//yes: encode with string delimiter			
+			g_string_append_c (node, '"' );
+			// " not inside inside ?
+			if( g_strstr_len(text, -1, "\"") == NULL )
+			{
+				//no: put native text
+				g_string_append (node, text);
+			}
+			else
+			{
+			//yes: double the text delimiter
+			GString *dtext = g_string_new(text);
+			
+				g_string_replace(dtext, "\"", "\"\"", 0);
+				g_string_append (node, dtext->str);
+				g_string_free(dtext, TRUE);
+			}
+			g_string_append_c (node, '"' );
+		}
+	}
+}
+
+
 static void list_txn_to_string_line(GString *node, gchar sep, Transaction *ope, guint32 kcat, gchar *memo, gdouble amount, gboolean hasstatus, gboolean hasacc)
 {
 Payee *payee;
@@ -637,28 +680,29 @@ char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 	hb_sprint_date(strbuf, ope->date);
 	g_string_append (node, strbuf );
 	g_string_append_c (node, sep );
-	
+
 	//paymode
 	g_snprintf(strbuf, sizeof (strbuf), "%d", ope->paymode);
 	g_string_append (node, strbuf );
 	g_string_append_c (node, sep );
 
 	//info
-	g_string_append (node, (ope->info != NULL) ? ope->info : "" );
+	//g_string_append (node, (ope->info != NULL) ? ope->info : "" );
+	list_txn_to_string_csv_text(node, &sep, ope->info);
 	g_string_append_c (node, sep );
-		
+
 	//payee	
 	payee = da_pay_get(ope->kpay);
-	g_string_append (node, (payee->name != NULL) ? payee->name : "");
+	//g_string_append (node, (payee->name != NULL) ? payee->name : "");
+	list_txn_to_string_csv_text(node, &sep, payee->name);
 	g_string_append_c (node, sep );
 
 	//memo
-	g_string_append (node, (memo != NULL) ? memo : "" );
+	//g_string_append (node, (memo != NULL) ? memo : "" );
+	list_txn_to_string_csv_text(node, &sep, memo);
 	g_string_append_c (node, sep );
 
 	//amount
-
-
 	//#793719
 	//g_ascii_dtostr (amountbuf, sizeof (amountbuf), ope->amount);
 	//#1750257 use locale numdigit
@@ -680,7 +724,8 @@ char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 	
 	//category
 	category = da_cat_get(kcat);
-	g_string_append (node, (category->fullname != NULL) ? category->fullname : "" );
+	//g_string_append (node, (category->fullname != NULL) ? category->fullname : "" );
+	list_txn_to_string_csv_text(node, &sep, category->fullname);
 	g_string_append_c (node, sep );
 
 	//tags
@@ -876,6 +921,15 @@ struct list_txn_data *data;
 }
 
 
+void list_txn_set_lockreconciled(GtkTreeView *treeview, gboolean lockreconciled)
+{
+struct list_txn_data *data;
+
+	data = g_object_get_data(G_OBJECT(treeview), "inst_data");
+
+	data->lockreconciled = lockreconciled;
+}
+
 void list_txn_set_warn_nocategory(GtkTreeView *treeview, gboolean warn)
 {
 struct list_txn_data *data;
@@ -1138,7 +1192,7 @@ gint i, col_id;
 			}
 		
 		}
-	
+
 		gtk_menu_attach_to_widget (GTK_MENU (menu), button, NULL);
 		#if( (GTK_MAJOR_VERSION == 3) && (GTK_MINOR_VERSION >= 22) )
 		gtk_menu_popup_at_pointer(GTK_MENU (menu), NULL);
@@ -1474,11 +1528,17 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Status"));
 
-	//renderer = gtk_cell_renderer_text_new ();
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	g_object_set(renderer, "xalign", 1.0, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_clr_cell_data_function, GINT_TO_POINTER(1), NULL);
+
 	renderer = gtk_cell_renderer_pixbuf_new();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_clr_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_clr_cell_data_function, GINT_TO_POINTER(2), NULL);
+
 	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CLR);
 	//gtk_tree_view_column_set_sort_indicator (column, FALSE);
