@@ -24,6 +24,8 @@
 enum {
 	LIST_TXN_TYPE_BOOK = 0,
 	LIST_TXN_TYPE_DETAIL,
+	LIST_TXN_TYPE_IMPOPE,
+	LIST_TXN_TYPE_XFERSOURCE,
 	LIST_TXN_TYPE_XFERTARGET
 };
 
@@ -41,6 +43,7 @@ struct list_txn_data
 	
 	gint				list_type;
 	gboolean			showall;
+	gboolean			lockreconciled;
 	gboolean			warnnocategory;
 	gboolean			tvc_is_visible;
 	gboolean			save_column_width;
@@ -60,6 +63,7 @@ Transaction *list_txn_get_active_transaction(GtkTreeView *treeview);
 
 GString *list_txn_to_string(GtkTreeView *treeview, gboolean isclipboard, gboolean hassplit, gboolean hasstatus, gboolean hasacc);
 
+void list_txn_set_lockreconciled(GtkTreeView *treeview, gboolean lockreconciled);
 void list_txn_set_save_column_width(GtkTreeView *treeview, gboolean save_column_width);
 void list_txn_sort_force(GtkTreeSortable *sortable, gpointer user_data);
 guint list_txn_get_quicksearch_column_mask(GtkTreeView *treeview);
