@@ -282,10 +282,10 @@ GtkTreeIter  iter;
 
 			if( (ope->date >= data->filter->mindate) && (ope->date <= data->filter->maxdate) )
 			{
-
 				//#1907699 date is wrong
-				//pos = report_interval_get_pos(tmpintvl, data->filter->mindate, ope);
-				pos = report_interval_get_pos(tmpintvl, data->jbasedate, ope);
+				//pos = report_interval_get_pos(tmpintvl, data->jbasedate, ope);
+				//#1970020 but with #1958001 fix, it is
+				pos = report_interval_get_pos(tmpintvl, data->filter->mindate, ope);
 
 				DB( g_print(" get '%s', pos=%d act=%d\n", ope->memo, pos, active) );
 
@@ -914,12 +914,6 @@ gint row;
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Balance report"));
 
-	//set the window icon
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_BALANCE);
-
-	//#1965594
-	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
-
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
