@@ -263,6 +263,10 @@ gboolean result;
 	{
 	Transaction *old_txn, *new_txn;
 
+		//#1909749 skip reconciled if lock is ON
+		if( PREFS->lockreconciled == TRUE && active_txn->status == TXN_STATUS_RECONCILED )
+			return;
+
 		old_txn = da_transaction_clone (active_txn);
 		new_txn = active_txn;
 		result = deftransaction_external_edit(GTK_WINDOW(data->window), old_txn, new_txn);
@@ -1195,12 +1199,6 @@ gint row;
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Budget report"));
 
-	//set the window icon
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_BUDGET);
-
-	//#1965594
-	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
-
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
