@@ -368,8 +368,20 @@ gchar *title;
 	}
 	else
 	{
-		// /!\ hazardous here
-		column = LST_REPDIST_EXPENSE+(tmptype)*2;
+		switch(tmptype)
+		{
+			case REPORT_TYPE_EXPENSE: 
+				column = LST_REPDIST_EXPENSE;
+				break;
+			case REPORT_TYPE_INCOME: 
+				column = LST_REPDIST_INCOME;
+				break;
+			default:
+			case REPORT_TYPE_TOTAL:
+				column = LST_REPDIST_TOTAL;
+				break;
+		} 
+
 		DB( g_print(" set bar to %d\n\n", column) );
 		gtk_chart_set_datas(GTK_CHART(data->RE_chart), model, column, title, NULL);
 	}
@@ -705,7 +717,7 @@ static void repstats_compute(GtkWidget *widget, gpointer user_data)
 struct repstats_data *data;
 DataTable *dt;
 gint tmpsrc, tmptype, tmpintvl;
-gdouble totexp, totinc;
+gdouble totexp, totinc, total_total;
 guint n_result, n_cols;
 guint i, n_inserted;
 GtkTreeModel *model;
@@ -743,9 +755,13 @@ GtkTreeIter  iter;
 	dt = report_compute_total(tmpsrc, data->filter, data->txn_queue);
 	if(dt)
 	{
-
 		data->total_expense = dt->totexp;
 		data->total_income  = dt->totinc;
+		total_total = dt->totexp + dt->totinc;
+
+		DB( g_printf(" total exp %9.2f\n", dt->totexp) );
+		DB( g_printf(" total inc %9.2f\n", dt->totinc) );
+		DB( g_printf(" total tot %9.2f\n", total_total) );
 
 		/* clear and detach our model */
 		gtk_list_store_clear (GTK_LIST_STORE(model));
@@ -758,6 +774,7 @@ GtkTreeIter  iter;
 		for(i=0; i<n_result; i++)
 		{
 		DataRow *dr = dt->rows[i];
+		gdouble drtotal;
 
 			//DB( g_print("try to insert item %d - %.2f %.2f\n", i, dr->expense[0], dr->income[1]) );
 
@@ -773,24 +790,33 @@ GtkTreeIter  iter;
 			if( tmpsrc == REPORT_SRC_ACCOUNT && i == 0 )
 				continue;
 
-			DB( g_printf(" insert %2d, '%s', %9.2f %9.2f %9.2f\n", i, dr->label, dr->expense[0], dr->income[1], -dr->expense[0] + dr->income[1]) );
-
 			n_inserted++;
 			totexp += dr->expense[0];
 			totinc += dr->income[1];
+			drtotal = dr->expense[0] + dr->income[1];
+			
 	    	gtk_list_store_insert_with_values (GTK_LIST_STORE(model), &iter, -1,
 		        LST_REPDIST_POS , dr->pos,
 		        LST_REPDIST_KEY , i,
 				LST_REPDIST_NAME, dr->label,
 				LST_REPDIST_EXPENSE, dr->expense[0],
 				LST_REPDIST_INCOME , dr->income[1],
-				LST_REPDIST_TOTAL  , dr->expense[0] + dr->income[1],
+				LST_REPDIST_TOTAL  , drtotal,
 				//#1925976 abs is used into hb_rate, no need to - expense
 				//#1942494 but when sum exp+inc, exp must be abs !
-				LST_REPDIST_EXPRATE, hb_rate(-dr->expense[0], -data->total_expense),
+				//#1988489 total must be computed with sign
+				LST_REPDIST_EXPRATE, hb_rate(dr->expense[0], data->total_expense),
 				LST_REPDIST_INCRATE, hb_rate(dr->income[1] , data->total_income),
-				LST_REPDIST_TOTRATE, hb_rate(-dr->expense[0] + dr->income[1], -data->total_expense + data->total_income),
+				LST_REPDIST_TOTRATE, hb_rate(drtotal, total_total),
 				-1);
+
+			DB( g_printf("\n insert %2d, '%s', %9.2f  %9.2f  %9.2f\n", i, dr->label, 
+				dr->expense[0], dr->income[1], drtotal) );
+
+			DB( g_printf(" rates  %2d, '%s', %9.2f%% %9.2f%% %9.2f%%\n", i, dr->label, 
+				hb_rate(dr->expense[0], data->total_expense), 
+				hb_rate(dr->income[1] , data->total_income), 
+				hb_rate(drtotal, total_total)) );
 		}
 
 		/* update column 0 title */
@@ -827,7 +853,7 @@ GtkTreeIter  iter;
 	}
 
 	
-	/* trend with test mutlti to remove */
+	/* trend with test multi to remove */
 	//TODO: add if mode==1 && choose a better max column value
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report2));
@@ -954,10 +980,12 @@ gint mode, type, page;
 	hb_widget_visible(data->BT_donut, visible);
 	hb_widget_visible(data->BT_stack, !visible);
 	hb_widget_visible(data->BT_stack100, !visible);
-	hb_widget_visible(data->BT_rate, visible);
 	hb_widget_visible(data->LB_intvl, !visible);
 	hb_widget_visible(data->CY_intvl, !visible);
 
+	visible = (mode==0 && page == 0) ? TRUE : FALSE;
+	hb_widget_visible(data->BT_rate, visible);
+
 	//zoom
 	visible = (data->charttype == CHART_TYPE_COL 
 			|| data->charttype == CHART_TYPE_STACK 
@@ -1003,6 +1031,10 @@ gboolean result;
 	{
 	Transaction *old_txn, *new_txn;
 
+		//#1909749 skip reconciled if lock is ON
+		if( PREFS->lockreconciled == TRUE && active_txn->status == TXN_STATUS_RECONCILED )
+			return;
+
 		old_txn = da_transaction_clone (active_txn);
 		new_txn = active_txn;
 		result = deftransaction_external_edit(GTK_WINDOW(data->window), old_txn, new_txn);
@@ -1458,10 +1490,6 @@ gint row;
 	DB( g_print(" - new window=%p, inst_data=%p\n", window, data) );
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Statistics Report"));
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_STATS);
-
-	//#1965594
-	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
 
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
