@@ -914,12 +914,6 @@ gint row, col;
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Vehicle cost report"));
 
-	//set the window icon
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_CAR);
-
-	//#1965594
-	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
-
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
