@@ -23,6 +23,9 @@
 #include "ui-currency.h"
 #include "ui-group.h"
 
+/****************************************************************************/
+/* Debug macros                                                             */
+/****************************************************************************/
 #define MYDEBUG 0
 
 #if MYDEBUG
@@ -146,8 +149,14 @@ GtkWidget *entry;
 	if( entry != NULL && GTK_IS_ENTRY(entry) )
 	{
 	Account *item = da_acc_get(key);
-
-		hbtk_entry_set_text(GTK_ENTRY(entry), item != NULL ? item->name : "");
+	gchar *txt = "";
+	
+		//#1972078 forbid set a closed account
+		if( (item != NULL) && !(item->flags & AF_CLOSED) )
+		{
+			txt = item->name;
+		}
+		hbtk_entry_set_text(GTK_ENTRY(entry), txt);
 	}
 }
 
@@ -1176,6 +1185,7 @@ gchar *retval = NULL;
 		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_SMALL);
 
 		getwidget = gtk_entry_new();
+		gtk_entry_set_width_chars(GTK_ENTRY(getwidget), 24);
 		gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, TRUE, TRUE, 0);
 		gtk_widget_show_all(mainvbox);
 
@@ -1573,7 +1583,8 @@ gint result;
 					GTK_WINDOW(data->dialog),
 					title,
 					secondtext,
-					_("_Delete")
+					_("_Delete"),
+					TRUE
 				);
 
 			g_free(title);
@@ -1842,9 +1853,6 @@ gint w, h, dw, dh, row;
 
 	data->dialog = dialog;
 
-	//set the dialog icon
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_ACCOUNT);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -1861,7 +1869,7 @@ gint w, h, dw, dh, row;
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainbox), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(mainbox), SPACING_LARGE);
 
 	hpaned = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (mainbox), hpaned, TRUE, TRUE, 0);
@@ -2011,6 +2019,7 @@ gint w, h, dw, dh, row;
 	
 	/* page :: Behaviour */
 	content_grid = gtk_grid_new();
+	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
 	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
 	label = gtk_label_new(_("Behaviour"));
@@ -2061,6 +2070,7 @@ gint w, h, dw, dh, row;
 
 	/* page :: Misc. */
 	content_grid = gtk_grid_new();
+	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
 	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
 	label = gtk_label_new(_("Misc."));
