@@ -419,7 +419,7 @@ GtkTreeViewColumn  *column;
 
 	#if MYDEBUG == 1
 	column = list_tpl_column_text_create(NULL, 0, list_tpl_cell_data_function_debugkey, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	#endif
 
 	/* column: Scheduled icon */
@@ -811,7 +811,8 @@ gint result;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -1112,8 +1113,6 @@ gint w, h, dw, dh;
 					    NULL);
 
 	data->dialog = dialog;
-	
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_ARCHIVE);
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
@@ -1123,7 +1122,7 @@ gint w, h, dw, dh;
 	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
 	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 
-	
+
 	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("\n[ui_scheduled] dialog=%p, inst_data=%p\n", dialog, data) );
@@ -1159,16 +1158,18 @@ gint w, h, dw, dh;
 	gtk_widget_set_halign(widget, GTK_ALIGN_END);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
-	//list + toolbar
+	// list + toolbar
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start (GTK_BOX (content), vbox, TRUE, TRUE, 0);
 	
 	// listview
 	scrollwin = gtk_scrolled_window_new(NULL,NULL);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
- 	treeview = (GtkWidget *)list_tpl_new();
-  	data->LV_arc = treeview;
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
+	//#1970509 enable hscrollbar
+	//gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	treeview = (GtkWidget *)list_tpl_new();
+	data->LV_arc = treeview;
 	gtk_widget_set_size_request(treeview, HB_MINWIDTH_LIST, -1);
 	gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
 	gtk_box_pack_start (GTK_BOX (vbox), scrollwin, TRUE, TRUE, 0);
@@ -1272,7 +1273,7 @@ gint w, h, dw, dh;
 	if(ext_arc != NULL)
 		list_tpl_select_by_pointer(GTK_TREE_VIEW(data->LV_arc), ext_arc);
 
-	//wait for the user
+	// wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	switch (result)
