@@ -24,6 +24,9 @@
 #include "ui-category.h"
 #include "ui-payee.h"
 
+/****************************************************************************/
+/* Debug macros                                                             */
+/****************************************************************************/
 #define MYDEBUG 0
 
 #if MYDEBUG
@@ -657,7 +660,8 @@ gint result;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -885,9 +889,6 @@ gint w, h, dw, dh, crow, row;
 
 	data->dialog = dialog;
 
-	//set the window icon
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_ASSIGN);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -897,9 +898,9 @@ gint w, h, dw, dh, crow, row;
 	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 
 
-	//store our window private data
+	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
-	DB( g_print("(ui_asg_manage_) window=%p, inst_data=%p\n", dialog, data) );
+	DB( g_print("(ui_asg_manage_) dialog=%p, inst_data=%p\n", dialog, data) );
 
 	//window contents
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));	 	// return a vbox
@@ -1122,7 +1123,7 @@ gint w, h, dw, dh, crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), entry1, 2, row, 2, 1);
 	
 
-	//connect all our signals
+	// connect all our signals
 	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
 
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_rul)), "changed", G_CALLBACK (ui_asg_manage_selection), NULL);
@@ -1149,7 +1150,7 @@ gint w, h, dw, dh, crow, row;
 	gtk_widget_show_all (dialog);
 	gtk_widget_hide(data->GR_wrntxt);
 
-	//wait for the user
+	// wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	// cleanup and destroy
