@@ -154,7 +154,7 @@ gchar type;
 
 	type = category_get_type_char(entry);
 
-	string = g_markup_printf_escaped("f:%d t:%c", entry->flags, type );
+	string = g_markup_printf_escaped("[%d] f:%d t:%c", entry->key, entry->flags, type );
 	g_object_set(renderer, "markup", string, NULL);
 	g_free(string);
 }
@@ -251,6 +251,14 @@ GtkTreeViewColumn  *column;
 	
 	/* category name */
 	renderer = gtk_cell_renderer_text_new ();
+
+	g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
+	    NULL);
+
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Category"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
@@ -919,7 +927,8 @@ gint result, i;
 			GTK_WINDOW(data->dialog),
 			title,
 			secondtext,
-			_("_Clear")
+			_("_Clear"),
+			TRUE
 		);
 
 	if( result == GTK_RESPONSE_OK )
@@ -1105,8 +1114,6 @@ gint crow, row;
 
 	data->dialog = dialog;
 
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_BUDGET);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -1123,7 +1130,7 @@ gint crow, row;
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));	 	// return a vbox
 
 	hpaned = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
-	gtk_container_set_border_width (GTK_CONTAINER(hpaned), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(hpaned), SPACING_LARGE);
 	gtk_box_pack_start (GTK_BOX (content_area), hpaned, TRUE, TRUE, 0);
 
 	/* left area */
