@@ -22,6 +22,9 @@
 
 #include "ui-category.h"
 
+/****************************************************************************/
+/* Debug macros                                                             */
+/****************************************************************************/
 #define MYDEBUG 0
 
 #if MYDEBUG
@@ -1596,7 +1599,8 @@ gboolean result;
 			GTK_WINDOW(data->dialog),
 			_("Delete unused categories"),
 			_("Are you sure you want to permanently\ndelete unused categories?"),
-			_("_Delete")
+			_("_Delete"),
+			TRUE
 		);
 
 	if( result == GTK_RESPONSE_OK )
@@ -1794,6 +1798,7 @@ GtkTreeIter			 iter;
 		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_MEDIUM);
 
 		w_name = gtk_entry_new();
+		gtk_entry_set_width_chars(GTK_ENTRY(w_name), 24);
 		gtk_entry_set_text(GTK_ENTRY(w_name), item->name);
 		gtk_widget_grab_focus (w_name);
 		gtk_box_pack_start (GTK_BOX (mainvbox), w_name, FALSE, FALSE, 0);
@@ -2063,7 +2068,8 @@ gint result;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -2317,8 +2323,6 @@ gint w, h, dw, dh, row;
 	data->dialog = dialog;
 	data->change = 0;
 
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_CATEGORY);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -2331,14 +2335,12 @@ gint w, h, dw, dh, row;
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("(defcategory) dialog=%p, inst_data=%p\n", dialog, data) );
 
-    g_signal_connect (dialog, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &dialog);
 
 	//dialog contents
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_LARGE);
 
     //our table
 	table = gtk_grid_new ();
@@ -2473,7 +2475,8 @@ gint w, h, dw, dh, row;
 	gtk_box_pack_start (GTK_BOX (hbox), data->ST_name2, TRUE, TRUE, 0);
 
 
-	//connect all our signals
+	// connect dialog signals
+    g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
 	g_object_bind_property (data->BT_add, "active", addreveal, "reveal-child", G_BINDING_BIDIRECTIONAL);
 
 	g_signal_connect (G_OBJECT (data->ST_name1), "activate", G_CALLBACK (ui_cat_manage_dialog_add), GINT_TO_POINTER(FALSE));
