@@ -1358,9 +1358,6 @@ gboolean retcode;
 }
 
 
-/*
-**
-*/
 static void ui_cur_manage_dialog_update(GtkWidget *treeview, gpointer user_data)
 {
 struct ui_cur_manage_dialog_data *data;
@@ -1408,10 +1405,6 @@ gboolean sensitive;
 }
 
 
-/**
- * ui_cur_manage_dialog_add:
- *
- */
 static void
 ui_cur_manage_dialog_add(GtkWidget *widget, gpointer user_data)
 {
@@ -1513,9 +1506,6 @@ GtkTreeIter			 iter;
 }
 
 
-/*
-** delete the selected curee to our treeview and temp GList
-*/
 static void ui_cur_manage_dialog_delete(GtkWidget *widget, gpointer user_data)
 {
 struct ui_cur_manage_dialog_data *data;
@@ -1551,7 +1541,8 @@ gboolean do_delete, result;
 					GTK_WINDOW(data->dialog),
 					title,
 					secondtext,
-					_("_Delete")
+					_("_Delete"),
+					TRUE
 				);
 
 			g_free(title);
@@ -1570,9 +1561,7 @@ gboolean do_delete, result;
 
 }
 
-/*
-** button callback: set base currency
-*/
+
 static void ui_cur_manage_dialog_setbase(GtkWidget *widget, gpointer user_data)
 {
 struct ui_cur_manage_dialog_data *data;
@@ -1604,11 +1593,6 @@ gboolean do_change;
 }
 
 
-
-
-/*
-**
-*/
 static void ui_cur_manage_dialog_selection(GtkTreeSelection *treeselection, gpointer user_data)
 {
 	ui_cur_manage_dialog_update(GTK_WIDGET(gtk_tree_selection_get_tree_view (treeselection)), NULL);
@@ -1629,10 +1613,6 @@ static void ui_cur_manage_dialog_onRowActivated (GtkTreeView        *treeview,
 }
 
 
-
-/*
-**
-*/
 static void ui_cur_manage_dialog_setup(struct ui_cur_manage_dialog_data *data)
 {
 
@@ -1649,9 +1629,6 @@ static void ui_cur_manage_dialog_setup(struct ui_cur_manage_dialog_data *data)
 }
 
 
-/*
-**
-*/
 GtkWidget *ui_cur_manage_dialog (void)
 {
 struct ui_cur_manage_dialog_data *data;
@@ -1673,9 +1650,6 @@ gint crow, row, w, h, dw, dh;
 	data->dialog = dialog;
 	data->change = 0;
 
-	//set the dialog icon
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_CURRENCY);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -1697,7 +1671,7 @@ gint crow, row, w, h, dw, dh;
 	content_grid = gtk_grid_new();
 	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
-	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_LARGE);
 	gtk_box_pack_start (GTK_BOX (content_area), content_grid, TRUE, TRUE, 0);
 
 	crow = 0;
