@@ -50,9 +50,21 @@ extern struct Preferences *PREFS;
 
 /* = = = = = = = = = = = = = = = = = = = = */
 
+
+static void my_ui_dialog_add_action_class(GtkDialog *dialog, gint response_id, gchar *class_name)
+{
+GtkWidget *button = gtk_dialog_get_widget_for_response(dialog, response_id);
+
+	if( button)
+	{
+		gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(button)), class_name);
+	}
+}
+
+
 /* Confirmation Alert dialog */
 
-gint ui_dialog_msg_confirm_alert(GtkWindow *parent, gchar *title, gchar *secondtext, gchar *actionverb)
+gint ui_dialog_msg_confirm_alert(GtkWindow *parent, gchar *title, gchar *secondtext, gchar *actionverb, gboolean destructive)
 {
 GtkWidget *dialog;
 gint retval;
@@ -75,7 +87,11 @@ gint retval;
 		g_object_set(GTK_MESSAGE_DIALOG (dialog), "secondary-text", secondtext, NULL);
 		//gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), secondtext);
 	}
-		
+
+	//5.6 style button
+	gchar *style = destructive ? GTK_STYLE_CLASS_DESTRUCTIVE_ACTION : GTK_STYLE_CLASS_SUGGESTED_ACTION;
+	my_ui_dialog_add_action_class(GTK_DIALOG(dialog), GTK_RESPONSE_OK, style);
+
 	gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 	
 	retval = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -184,7 +200,7 @@ gint row, count, count2;
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
-	gtk_container_set_border_width (GTK_CONTAINER(box), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(box), SPACING_LARGE);
 	gtk_box_pack_start (GTK_BOX (content_area), box, FALSE, FALSE, 0);
 
 	// group :: file title
@@ -710,8 +726,7 @@ gboolean retval;
 gboolean ui_dialog_msg_savechanges(GtkWidget *widget, gpointer user_data)
 {
 gboolean retval = TRUE;
-GtkWidget *dialog = NULL;
-
+GtkWidget *dialog;
 
   	if(GLOBALS->changes_count)
 	{
@@ -738,6 +753,9 @@ GtkWidget *dialog = NULL;
 			_("_Save"), 2,
 			NULL);
 
+		//5.6 style button
+		my_ui_dialog_add_action_class(GTK_DIALOG(dialog), 0, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
+
 		gtk_dialog_set_default_response(GTK_DIALOG( dialog ), 2);
 
 		result = gtk_dialog_run( GTK_DIALOG( dialog ) );
@@ -1035,39 +1053,49 @@ gint crow, row;
 struct xfer_data
 {
 	GtkWidget   *dialog;
-	GtkWidget	*radio[2];
 	GtkWidget	*srctreeview;
 	GtkWidget	*lb_several;
 	GtkWidget	*treeview;
 };
 
 
-static void ui_dialog_transaction_xfer_select_child_cb(GtkWidget *radiobutton, gpointer user_data)
+//#1982036 make releavant column to be displayed
+static gint lst_xfer_columns[NUM_LST_DSPOPE+1] = {
+	LST_DSPOPE_STATUS,
+	LST_DSPOPE_MATCH,
+	LST_DSPOPE_ACCOUNT,
+	LST_DSPOPE_DATE,
+	LST_DSPOPE_AMOUNT,
+	LST_DSPOPE_CLR,
+	LST_DSPOPE_MEMO,
+	LST_DSPOPE_INFO,
+	LST_DSPOPE_PAYEE,
+	LST_DSPOPE_CATEGORY,
+	LST_DSPOPE_TAGS,
+	-LST_DSPOPE_EXPENSE,
+	-LST_DSPOPE_INCOME,
+	-LST_DSPOPE_BALANCE
+};
+
+
+static void ui_dialog_transaction_xfer_select_child_cb(GtkWidget *widget, gpointer user_data)
 {
 struct xfer_data *data;
 GtkTreeSelection *selection;
-gboolean btnew, sensitive;
+gboolean sensitive;
 gint count;
 
-	DB( g_print("(import) account type toggle\n") );
-	
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(radiobutton), GTK_TYPE_WINDOW)), "inst_data");
+	DB( g_print("\n(xfer select) toggle choice\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
-	btnew = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->radio[0]));
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview));
 	count = gtk_tree_selection_count_selected_rows(selection);
 
-	if(btnew)
-		gtk_tree_selection_unselect_all(selection);
+	sensitive = (count > 0) ? TRUE : FALSE;
+	gtk_dialog_set_response_sensitive(GTK_DIALOG(data->dialog), HB_RESPONSE_SELECTION, sensitive);
 
-	sensitive = btnew^1;
-	gtk_widget_set_sensitive(data->lb_several, sensitive);
-	gtk_widget_set_sensitive(data->treeview, sensitive);
-	
-	sensitive = (btnew || count > 0) ? TRUE : FALSE;
-	gtk_dialog_set_response_sensitive(GTK_DIALOG(data->dialog), GTK_RESPONSE_ACCEPT, sensitive);
-
-	DB( g_print("test count %d btnew %d sensitive %d\n", count, btnew, sensitive) );
+	DB( g_print(" test count %d sensitive %d\n", count, sensitive) );
 
 }
 
@@ -1080,78 +1108,94 @@ static void ui_dialog_transaction_xfer_select_child_selection_cb(GtkTreeSelectio
 gint ui_dialog_transaction_xfer_select_child(GtkWindow *parent, Transaction *stxn, GList *matchlist, Transaction **child)
 {
 struct xfer_data *data;
-GtkWidget *window, *content, *mainvbox, *vbox, *sw, *label;
-GtkTreeModel		 *newmodel;
-GtkTreeIter			 newiter;
+GtkWidget *dialog, *content, *mainvbox, *sw, *label;
+GtkTreeModel *newmodel;
+GtkTreeIter newiter;
+
+	DB( g_print("\n(xfer select) new\n") );
+
 
 	data = g_malloc0(sizeof(struct xfer_data));
 	if(!data) return 0;
 	
-	window = gtk_dialog_new_with_buttons (
-    			_("Select among possible transactions..."),
+	dialog = gtk_dialog_new_with_buttons (
+    			_("Select action for target creation"),
     			parent,
 			    0,
 			    _("_Cancel"), GTK_RESPONSE_CANCEL,
-			    _("_OK"), GTK_RESPONSE_ACCEPT,
+			    _("Create _New"), HB_RESPONSE_CREATE_NEW,
+			    _("Use _Selection"), HB_RESPONSE_SELECTION,
 			    NULL);
 
-	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
-	data->dialog = window;
+	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
+	data->dialog = dialog;
 
-	//gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
-	gtk_window_set_default_size (GTK_WINDOW (window), 800, 494);
+	//5/6 set a nice dialog size
+/*
+	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
+	dh = (h*1.33/PHI);
+	//ratio 3:2
+	dw = (dh * 3) / 2;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
+*/
 
-	content = gtk_dialog_get_content_area(GTK_DIALOG (window));
-		mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_SMALL);
+	//hide close button
+	//gtk_window_set_deletable(GTK_WINDOW(dialog), FALSE);
+
+	//gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
+	//gtk_window_set_default_size (GTK_WINDOW (dialog), 800, 494);
+
+	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
+
+	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_LARGE);
+
+	label = make_label_group(_("Source transfer"));
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
 	// source listview
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	//gtk_widget_set_size_request(sw, -1, HB_MINWIDTH_LIST/2);
+//	gtk_widget_set_size_request(sw, -1, HB_MINWIDTH_LIST/2);
+	gtk_widget_set_margin_left(sw, SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (mainvbox), sw, FALSE, FALSE, 0);
 
-	data->srctreeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
+	data->srctreeview = create_list_transaction(LIST_TXN_TYPE_XFERSOURCE, lst_xfer_columns);
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->srctreeview)), GTK_SELECTION_NONE);
 	gtk_container_add (GTK_CONTAINER (sw), data->srctreeview);
-	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
 
 
-	// actions 
-	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (mainvbox), vbox, FALSE, TRUE, SPACING_SMALL);
-
-	label = make_label(_("Select an action:"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-
-	data->radio[0] = gtk_radio_button_new_with_label (NULL, _("create a new transaction"));
-	gtk_box_pack_start (GTK_BOX (vbox), data->radio[0], FALSE, FALSE, 0);
-
-	data->radio[1] = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (data->radio[0]), _("select an existing transaction"));
-	gtk_box_pack_start (GTK_BOX (vbox), data->radio[1], FALSE, FALSE, 0);
-
+	// target listview
+	label = make_label_group(_("Target association suggested"));
+	gtk_widget_set_margin_top(label, SPACING_LARGE);
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
 	label = make_label(_(
 		"HomeBank has found some transaction that may be " \
 		"the associated transaction for the internal transfer."), 0.0, 0.5
 		);
 	data->lb_several = label;
-	gimp_label_set_attributes (GTK_LABEL (label),
+	gtk_widget_set_margin_left(label, SPACING_MEDIUM);
+	/*gimp_label_set_attributes (GTK_LABEL (label),
                              PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL,
-                             -1);
-	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, SPACING_SMALL);
+                             -1);*/
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
-	// target listview
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_widget_set_size_request(sw, -1, HB_MINWIDTH_LIST*1.5);
+	gtk_widget_set_margin_left(sw, SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
 
-	data->treeview = create_list_transaction(LIST_TXN_TYPE_XFERTARGET, PREFS->lst_ope_columns);
+	data->treeview = create_list_transaction(LIST_TXN_TYPE_XFERTARGET, lst_xfer_columns);
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview)), GTK_SELECTION_SINGLE);
 	gtk_container_add (GTK_CONTAINER (sw), data->treeview);
-	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
+
+	DB( g_print(" populate src\n") );
 
 	/* populate source */
 	if( stxn != NULL )
@@ -1163,11 +1207,13 @@ GtkTreeIter			 newiter;
 
 		//#1830523/#1840393
 		gtk_list_store_set (GTK_LIST_STORE(newmodel), &newiter,
-		MODEL_TXN_POINTER, stxn,
-		MODEL_TXN_SPLITAMT, stxn->amount,
-		-1);
+			MODEL_TXN_POINTER, stxn,
+			MODEL_TXN_SPLITAMT, stxn->amount,
+			-1);
 	}
 
+	DB( g_print(" populate src\n") );
+
 	/* populate target */
 	newmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(data->treeview));
 	gtk_list_store_clear (GTK_LIST_STORE(newmodel));
@@ -1192,47 +1238,36 @@ GtkTreeIter			 newiter;
 	}
 
 
-	g_signal_connect (data->radio[0], "toggled", G_CALLBACK (ui_dialog_transaction_xfer_select_child_cb), NULL);
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview)), "changed", G_CALLBACK (ui_dialog_transaction_xfer_select_child_selection_cb), NULL);
 
 	gtk_widget_show_all(mainvbox);
 
+	//#1982036 show essential field on the left : no need to leave space
+	DB( g_print(" autosize\n") );
+
+	gtk_tree_view_columns_autosize(GTK_TREE_VIEW(data->srctreeview));
+	gtk_tree_view_columns_autosize(GTK_TREE_VIEW(data->treeview));
+
+	//5.5.7: add sort by match descending
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(newmodel), LST_DSPOPE_MATCH, GTK_SORT_DESCENDING);
+
 	//initialize
-	gtk_widget_set_sensitive (data->radio[1], TRUE);
-	if( g_list_length (matchlist) <= 0 )
-	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->radio[0]), TRUE);
-		gtk_widget_set_sensitive (data->radio[1], FALSE);
-		gtk_widget_set_visible (data->lb_several, FALSE);
-	}
-	else
-	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->radio[1]), TRUE);
-		gtk_widget_set_visible (data->lb_several, TRUE);
-	}
-	
-	ui_dialog_transaction_xfer_select_child_cb(data->radio[0], NULL);
+	gtk_dialog_set_response_sensitive(GTK_DIALOG(data->dialog), HB_RESPONSE_SELECTION, FALSE);
 
 	//wait for the user
-	gint result = gtk_dialog_run (GTK_DIALOG (window));
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	*child = NULL;	
-	if(result == GTK_RESPONSE_ACCEPT)
+	*child = NULL;
+	if(result == HB_RESPONSE_SELECTION)
 	{
-	gboolean bnew;
+	GtkTreeSelection *selection;
+	GtkTreeModel		 *model;
+	GtkTreeIter			 iter;
 
-		bnew = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->radio[0]));
-		if( bnew == FALSE )
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview));
+		if (gtk_tree_selection_get_selected(selection, &model, &iter))
 		{
-		GtkTreeSelection *selection;
-		GtkTreeModel		 *model;
-		GtkTreeIter			 iter;
-
-			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->treeview));
-			if (gtk_tree_selection_get_selected(selection, &model, &iter))
-			{
-				gtk_tree_model_get(model, &iter, MODEL_TXN_POINTER, child, -1);
-			}
+			gtk_tree_model_get(model, &iter, MODEL_TXN_POINTER, child, -1);
 		}
 	}
 
@@ -1240,12 +1275,10 @@ GtkTreeIter			 newiter;
 
 	
 	// cleanup and destroy
-	gtk_widget_destroy (window);
+	gtk_widget_destroy (dialog);
 
 	g_free(data);
 	
 	return result;
 }
 
-
-
