@@ -1443,10 +1443,6 @@ gint w, h, dw, dh;
 	gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Cancel"),	GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button(GTK_DIALOG(dialog), _("_OK"),    GTK_RESPONSE_ACCEPT);
 
-
-	//TODO:
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_FILTER);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
