@@ -1192,7 +1192,8 @@ gboolean result;
 			GTK_WINDOW(data->dialog),
 			_("Delete unused payee"),
 			_("Are you sure you want to\npermanently delete unused payee?"),
-			_("_Delete")
+			_("_Delete"),
+			TRUE
 		);
 
 	if( result == GTK_RESPONSE_OK )
@@ -1362,6 +1363,7 @@ guint32 key;
 		label = make_label_widget(_("_Name:"));
 		gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 		widget = gtk_entry_new();
+		gtk_entry_set_width_chars(GTK_ENTRY(widget), 24);
 		ST_name = widget;
 		gtk_widget_set_hexpand(widget, TRUE);
 		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
@@ -1632,7 +1634,8 @@ gint result;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -1741,8 +1744,6 @@ gint w, h, dw, dh, row;
 	data->dialog = dialog;
 	data->change = 0;
 
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_PAYEE);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -1762,7 +1763,7 @@ gint w, h, dw, dh, row;
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_LARGE);
 
     //our table
 	table = gtk_grid_new ();
@@ -1770,6 +1771,7 @@ gint w, h, dw, dh, row;
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
 	gtk_box_pack_start (GTK_BOX (mainvbox), table, TRUE, TRUE, 0);
 
+	//filter part
 	row = 0;
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
 	gtk_grid_attach (GTK_GRID (table), bbox, 0, row, 2, 1);
@@ -1796,7 +1798,7 @@ gint w, h, dw, dh, row;
 	
 	gtk_widget_show_all (menu);
 
-	
+
 	widget = gtk_menu_button_new();
 	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
 	g_object_set (widget, "image", image, "popup", GTK_MENU(menu),  NULL);
