@@ -1018,6 +1018,8 @@ GdkRGBA rgba;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_show_remind), PREFS->showremind);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_show_void), PREFS->showvoid);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_include_remind), PREFS->includeremind);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_lock_reconciled), PREFS->lockreconciled);
+	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_herit_date), PREFS->heritdate);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_show_confirm), PREFS->txn_showconfirm);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_memoacp), PREFS->txn_memoacp);
@@ -1142,6 +1144,7 @@ const gchar *datfmt;
 	PREFS->showremind = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_show_remind));
 	PREFS->showvoid = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_show_void));
 	PREFS->includeremind = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_include_remind));
+	PREFS->lockreconciled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_lock_reconciled));
 	PREFS->heritdate = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_herit_date));
 	PREFS->txn_showconfirm = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_show_confirm));
 	PREFS->txn_memoacp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_memoacp));
@@ -1744,6 +1747,11 @@ gint crow, row;
 	data->CM_include_remind = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 3, 1);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Lock reconciled for any changes"));
+	data->CM_lock_reconciled = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 3, 1);
+
 
 	// group :: Add/Edit
     group_grid = gtk_grid_new ();
@@ -2242,7 +2250,8 @@ gint result;
 		GTK_WINDOW(data->dialog),
 		_("Reset All Preferences"),
 		_("Do you really want to reset\nall preferences to default\nvalues?"),
-	    _("_Reset")
+	    _("_Reset"),
+		TRUE
 		);
 	if( result == GTK_RESPONSE_OK )
 	{
@@ -2278,8 +2287,6 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
 
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_PREFERENCES);
-
 	content = gtk_dialog_get_content_area(GTK_DIALOG (window));			// return a vbox
 	mainvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, SPACING_MEDIUM);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
