@@ -29,8 +29,6 @@
 #include "hb-split.h"
 
 
-
-
 /****************************************************************************/
 /* Debug macros                                                             */
 /****************************************************************************/
@@ -51,6 +49,8 @@ extern struct Preferences *PREFS;
 
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+
 static void list_split_number_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 GtkTreePath *path;
@@ -78,7 +78,7 @@ gchar *color, *format;
 	gtk_tree_model_get(model, iter, 0, &split, -1);
 
 	//hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, amount, ope->kcur, GLOBALS->minor);
-	format = g_object_get_data(G_OBJECT(col), "format");
+	format = g_object_get_data(G_OBJECT(col), "format_data");
 	
 	amount = split->amount;
 	g_snprintf(buf, G_ASCII_DTOSTR_BUF_SIZE-1, format, amount);
@@ -145,7 +145,7 @@ gint count, i;
 	{
 		split = da_splits_get(splits, i);
 
-		DB( g_print("- set split %d : %d, %.2f, %s\n", i, split->kcat, split->amount, split->memo) );
+		DB( g_print(" append split %d : %d, %.2f, '%s'\n", i, split->kcat, split->amount, split->memo) );
 
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
@@ -237,7 +237,7 @@ GtkTreeViewColumn	*column;
 	g_object_set(renderer, "xalign", 1.0, NULL);
 
 	column = gtk_tree_view_column_new_with_attributes(_("Amount"), renderer, NULL);
-	g_object_set_data(G_OBJECT(column), "format", format);
+	g_object_set_data(G_OBJECT(column), "format_data", format);
 	
 	gtk_tree_view_column_set_alignment (column, 1.0);
 	gtk_tree_view_column_set_resizable(column, TRUE);
@@ -316,7 +316,7 @@ guint i;
 		gtk_tree_model_get (model, &iter, 0, &split, -1);
 		split->pos = i;
 
-		DB( g_print("split pos: %d '%s' %.2f\n", i, split->memo, split->amount) );
+		DB( g_print(" split pos: %d '%s' %.2f\n", i, split->memo, split->amount) );
 		
 		i++; valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 	}
@@ -325,32 +325,26 @@ guint i;
 }
 
 
-static void ui_split_dialog_cb_eval_split(GtkWidget *widget, gpointer user_data)
+static gboolean ui_split_dialog_cb_amount_focus_out (GtkEditable *spin_button, GdkEvent  *event, gpointer user_data)
 {
 struct ui_split_dialog_data *data;
-gboolean sensitive;
-gdouble amount;
 const gchar *txt;
-guint count;
-	
-	DB( g_print("\n[ui_split_dialog] eval split\n") );
 
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
+	DB( g_print("\n[ui_split_dialog] cb amount focus out\n") );
 
-	amount = g_strtod(gtk_entry_get_text(GTK_ENTRY(data->ST_amount)), NULL);
-	sensitive = hb_amount_round(amount, data->cur->frac_digits) != 0.0 ? TRUE : FALSE;
-	gtk_widget_set_sensitive (data->BT_apply, sensitive);
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(spin_button), GTK_TYPE_WINDOW)), "inst_data");
 
-	count = da_splits_length (data->tmp_splits);
-	sensitive = ( count >= TXN_MAX_SPLIT ) ? FALSE : TRUE;
-	gtk_widget_set_sensitive (data->BT_add, sensitive);
+	txt = gtk_entry_get_text(GTK_ENTRY(spin_button));
 
-	//#5.4.3 get a sign -/+
-	txt = gtk_entry_get_text(GTK_ENTRY(data->ST_amount));
-	data->amtsigned = (*txt == '-' || *txt == '+') ? TRUE : FALSE;
+	data->isopposite = FALSE;
+	if( ((data->txntype == TXN_TYPE_EXPENSE) && (*txt == '+')) || ((data->txntype == TXN_TYPE_INCOME) && (*txt == '-')) )
+	{
+		data->isopposite = TRUE;
+	}
 
-	DB( g_print(" - txt='%s' amt=%.2f, signed=%d, nbsplit=%d\n", txt, amount, data->amtsigned, count) );
+	DB( g_print(" txt='%s'\n amt=%.8f\n opp=%d\n", txt, gtk_spin_button_get_value (GTK_SPIN_BUTTON(spin_button)), data->isopposite) );
 
+	return FALSE;
 }
 
 
@@ -375,8 +369,6 @@ guint count;
 	tmpval = (count > 1) ? TRUE : FALSE;
 	gtk_widget_set_sensitive (data->BT_remall, (data->isedited) ? FALSE : tmpval);
 
-	ui_split_dialog_cb_eval_split(widget, NULL);
-	
 	//btn: add/apply
 	/*amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 	tmpval = hb_amount_round(amount, 2) != 0.0 ? TRUE : FALSE;
@@ -406,18 +398,12 @@ struct ui_split_dialog_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
-	g_signal_handler_block(data->PO_cat, data->hid_cat);
-	g_signal_handler_block(data->ST_amount, data->hid_amt);
-
 	//ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), 0);
 	ui_cat_entry_popover_set_active(GTK_BOX(data->PO_cat), 0);
 	if( data->mode == SPLIT_MODE_EMPTY )
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), 0.0);
 	gtk_entry_set_text(GTK_ENTRY(data->ST_memo), "");
 
-	g_signal_handler_unblock(data->ST_amount, data->hid_amt);
-	g_signal_handler_unblock(data->PO_cat, data->hid_cat);
-
 	gtk_widget_grab_focus(data->ST_amount);
 	
 	data->isedited = FALSE;
@@ -477,7 +463,7 @@ GtkTreeSelection *selection;
 GtkTreeModel		 *model;
 GtkTreeIter			 iter;
 
-	DB( g_print("\n[ui_split_dialog] apply\n") );
+	DB( g_print("--------\n[ui_split_dialog] apply\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -488,6 +474,7 @@ GtkTreeIter			 iter;
 	gdouble amount;
 
 		gtk_tree_model_get(model, &iter, 0, &split, -1);
+		DB( g_print(" update spin\n") );
 		gtk_spin_button_update (GTK_SPIN_BUTTON(data->ST_amount));
 		amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 		if(amount)
@@ -561,31 +548,34 @@ Split *split;
 guint count;
 gdouble amount;
 
-	DB( g_print("\n[ui_split_dialog] add\n") );
+	DB( g_print("--------\n[ui_split_dialog] add\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
 	count = da_splits_length (data->tmp_splits);
+	DB( g_print(" n_split: %d (of %d)\n", count, TXN_MAX_SPLIT) );
+	
 	if( count <= TXN_MAX_SPLIT )
 	{
-	gboolean amtsigned;
-	
 		split = da_split_malloc ();
-		//preserve amtsigned, resetted with gtk_spin_button_update
-		amtsigned = data->amtsigned;
+		//5.4.4
+		DB( g_print(" update spin\n") );
 		gtk_spin_button_update (GTK_SPIN_BUTTON(data->ST_amount));
 		amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 		if(amount)
 		{
-			//#5.4.3 force sign only if the input has no sign
-			//#1880386 	wish: revert ease to combine expense/income in splits dialog
-			if( amtsigned == FALSE )
+			//by default affect txntype sign
+			if( data->txntype == TXN_TYPE_EXPENSE && amount > 0 )
 			{
-				//#1848604 force sign according txn type
-				if( hb_amount_type_match(amount, data->txntype) == FALSE)
-					amount *= -1;
+				DB( g_print(" force expense\n") );
+				amount *= -1;
+			}
+			//but take opposite into account
+			if( data->isopposite == TRUE )
+			{
+				DB( g_print(" force opposite\n") );
+				amount *= -1;
 			}
-
 			//split->amount = amount;
 			//#1910819 must round frac digit
 			split->amount = hb_amount_round(amount, data->cur->frac_digits);
@@ -594,7 +584,7 @@ gdouble amount;
 			split->kcat = ui_cat_entry_popover_get_key_add_new(GTK_BOX(data->PO_cat));
 			split->memo = g_strdup((gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_memo)));
 
-			DB( g_print("- get split : %d, %.2f, %s\n", split->kcat, split->amount, split->memo) );
+			DB( g_print(" append split : %d, %.2f, %s\n", split->kcat, split->amount, split->memo) );
 
 			da_splits_append (data->tmp_splits, split);
 
@@ -612,7 +602,10 @@ gdouble amount;
 			da_split_free(split);
 		}
 	}
-	//todo: msg max number reached
+	else
+	{
+		g_warning("split error: limit of %d reached", TXN_MAX_SPLIT);
+	}
 	
 	ui_split_dialog_edit_end(widget, user_data);
 	ui_split_dialog_update (widget, user_data);
@@ -627,6 +620,10 @@ struct ui_split_dialog_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
 
+	//we trigger the focus-out-event on spinbutton, with grab the add button
+	//because we also do things before the legacy spinbutton fucntion
+	gtk_widget_grab_focus(data->BT_add);
+
 	if( data->isedited == TRUE )
 		ui_split_dialog_apply_cb(widget, NULL);
 	else
@@ -634,7 +631,7 @@ struct ui_split_dialog_data *data;
 }
 
 
-static void ui_split_rowactivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer user_data)
+static void ui_split_rowactivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer user_data)
 {
 	DB( g_print("\n[ui_split_dialog] rowactivated\n") );
 
@@ -687,7 +684,7 @@ gboolean valid;
 	}
 	count = i;
 
-	DB( g_print("- count=%d, nbvalid=%d\n", count, nbvalid ) );
+	DB( g_print(" n_count=%d, n_valid=%d\n", count, nbvalid ) );
 	
 	data->remsplit = data->amount - data->sumsplit;
 
@@ -753,7 +750,7 @@ guint count;
 	count = da_splits_length(data->tmp_splits);
 	data->nbsplit = count > 1 ? count-1 : 0;
 
-	DB( g_print("- count = %d\n", count) );
+	DB( g_print(" n_count = %d\n", count) );
 	list_split_populate (data->LV_split, data->tmp_splits);
 
 	data->isedited = FALSE;
@@ -790,7 +787,7 @@ Currency *cur;
 					    NULL);
 
 	//store our dialog private data
-	DB( g_print(" - window=%p\n", dialog) );
+	DB( g_print(" window=%p\n", dialog) );
 
     g_signal_connect (dialog, "destroy",
 			G_CALLBACK (gtk_widget_destroyed), &dialog);
@@ -860,7 +857,7 @@ gint row;
 
 	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
-	DB( g_print(" - window=%p, inst_data=%p\n", dialog, data) );
+	DB( g_print(" window=%p, inst_data=%p\n", dialog, data) );
 
     g_signal_connect (dialog, "destroy",
 			G_CALLBACK (gtk_widget_destroyed), &dialog);
@@ -882,6 +879,10 @@ gint row;
 	data->amount = amount;
 	data->sumsplit = amount;
 
+	DB( g_print(" amount : %f\n", data->amount) );
+	DB( g_print(" txntype: %s\n", data->txntype == TXN_TYPE_EXPENSE ? "expense" : "income" ));
+	DB( g_print(" mode   : %s\n", data->mode == SPLIT_MODE_AMOUNT ? "amount" : "empty" ));
+
 	if( *src_splits != NULL )
 		data->tmp_splits = da_splits_clone(*src_splits); 
 	else
@@ -891,7 +892,7 @@ gint row;
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
 	table = gtk_grid_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (table), SPACING_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (table), SPACING_LARGE);
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_TINY);
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_TINY);
 	gtk_box_pack_start (GTK_BOX (content), table, TRUE, TRUE, 0);
@@ -1027,22 +1028,14 @@ gint row;
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_split)), "changed", G_CALLBACK (ui_split_selection), data);
 	g_signal_connect (GTK_TREE_VIEW(data->LV_split), "row-activated", G_CALLBACK (ui_split_rowactivated), data);
 
-	g_signal_connect (data->ST_memo, "insert-text", G_CALLBACK(ui_split_dialog_filter_text_handler), data);
-	
-	//data->hid_cat = g_signal_connect (data->PO_cat , "changed"    , G_CALLBACK (ui_split_dialog_cb_eval_split), data);
-	data->hid_cat = g_signal_connect (ui_cat_entry_popover_get_entry(GTK_BOX(data->PO_cat)), "changed"    , G_CALLBACK (ui_split_dialog_cb_eval_split), data);
-
-	data->hid_amt = g_signal_connect (data->ST_amount, "changed", G_CALLBACK (ui_split_dialog_cb_eval_split), data);
-	//data->hid_amt = g_signal_connect (data->ST_amount, "value-changed", G_CALLBACK (ui_split_dialog_cb_eval_split), data);
-
-	//todo: add enter validate
-	g_signal_connect (data->ST_amount, "activate", G_CALLBACK (ui_split_dialog_cb_activate_split), NULL);
-
-	
 	g_signal_connect (data->BT_edit  , "clicked", G_CALLBACK (ui_split_dialog_edit_start), NULL);
 	g_signal_connect (data->BT_rem   , "clicked", G_CALLBACK (ui_split_dialog_delete_cb), NULL);
 	g_signal_connect (data->BT_remall, "clicked", G_CALLBACK (ui_split_dialog_deleteall_cb), NULL);
 
+	g_signal_connect (data->ST_memo  , "insert-text", G_CALLBACK(ui_split_dialog_filter_text_handler), data);
+	g_signal_connect (data->ST_amount, "focus-out-event", G_CALLBACK (ui_split_dialog_cb_amount_focus_out), data);
+	g_signal_connect (data->ST_amount, "activate", G_CALLBACK (ui_split_dialog_cb_activate_split), NULL);
+
 	g_signal_connect (data->BT_add   , "clicked", G_CALLBACK (ui_split_dialog_add_cb), NULL);
 	g_signal_connect (data->BT_apply , "clicked", G_CALLBACK (ui_split_dialog_apply_cb), NULL);
 	g_signal_connect (data->BT_cancel, "clicked", G_CALLBACK (ui_split_dialog_cancel_cb), NULL);
