@@ -56,17 +56,14 @@ struct ui_split_dialog_data
 	Currency	*cur;
 	 
 	gdouble		amount;
-	gboolean	amtsigned;
+	gboolean	isopposite;	
+
 	gdouble		sumsplit;
 	gdouble		remsplit;
 
 	gboolean	isedited;
 	gint		nbsplit;
 	gint		activeline;
-
-	gulong		hid_cat;
-	gulong		hid_amt;
-	
 };
 
 
