@@ -566,17 +566,25 @@ guint32 key;
 		label = make_label_widget(_("_Name:"));
 		gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 		widget = gtk_entry_new();
+		gtk_entry_set_width_chars(GTK_ENTRY(widget), 24);
 		ST_name = widget;
 		gtk_widget_set_hexpand(widget, TRUE);
 		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
+		//setup
+		//#1992284 manage tag edit input is empty
+		gtk_entry_set_text(GTK_ENTRY(ST_name), item->name);
+		gtk_widget_grab_focus (ST_name);
+
+		gtk_entry_set_activates_default (GTK_ENTRY(ST_name), TRUE);
+
+		gtk_dialog_set_default_response(GTK_DIALOG( dialog ), GTK_RESPONSE_ACCEPT);
+
+
 		g_signal_connect (G_OBJECT (ST_name), "changed", G_CALLBACK (ui_tag_manage_dialog_edit_entry_cb), dialog);
 
 		gtk_widget_show_all(content_grid);
 
-
-		gtk_dialog_set_default_response(GTK_DIALOG( dialog ), GTK_RESPONSE_ACCEPT);
-
 		//wait for the user
 		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -769,7 +777,8 @@ gint result;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -861,8 +870,6 @@ gint w, h, dw, dh, row;
 	data->dialog = dialog;
 	data->change = 0;
 
-	//gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_TAG);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
@@ -883,7 +890,7 @@ gint w, h, dw, dh, row;
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_MEDIUM);
+	gtk_container_set_border_width (GTK_CONTAINER(mainvbox), SPACING_LARGE);
 
     //our table
 	table = gtk_grid_new ();
