@@ -608,7 +608,6 @@ void deftransaction_get(GtkWidget *widget, gpointer user_data)
 struct deftransaction_data *data;
 Transaction *entry;
 gchar *txt;
-gdouble value;
 gint type, active;
 
 	DB( g_print("\n[ui-transaction] get\n") );
@@ -616,12 +615,10 @@ gint type, active;
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	entry = data->ope;
-
-	DB( g_print(" - ope = %p\n", entry) );
+	DB( g_print(" txn: %p\n", entry) );
 
 	//if( entry == NULL )
 	//	return;
-
 	
 	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
 	entry->flags &= ~(OF_INCOME|OF_INTXFER);
@@ -629,13 +626,23 @@ gint type, active;
 		entry->flags |= OF_INCOME;
 	if( type == TXN_TYPE_INTXFER)
 		entry->flags |= OF_INTXFER;
+	DB( g_print(" type: %d\n", type) );
 
-	DB( g_print(" get type to %d\n", type) );
-
-	
-	//DB( g_print(" get date to %d\n", entry->ope_Date) );
 	entry->date = gtk_date_entry_get_date(GTK_DATE_ENTRY(data->PO_date));
-	//g_object_get(GTK_DATE_ENTRY(data->PO_date), "date", entry->ope_Date);
+	DB( hb_print_date(entry->date, " date:") );
+
+	//#1988594 ensure amount are updated
+	gtk_spin_button_update(GTK_SPIN_BUTTON(data->ST_amount));
+	
+	entry->amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+	DB( g_print(" amount: %f '%s'\n", entry->amount, gtk_entry_get_text(GTK_ENTRY(data->ST_amount))) );
+
+	//entry->kacc     = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
+	entry->kacc     = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_acc));
+	//entry->kxferacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_accto));
+	entry->kxferacc = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_accto));
+	DB( g_print(" srcacc: %d\n", entry->kacc) );
+	DB( g_print(" dstacc: %d\n", entry->kxferacc) );
 
 	//free any previous string
 	if(	entry->memo )
@@ -662,11 +669,8 @@ gint type, active;
 				0, txt, 
 				-1);
 		}
-
 	}
-
-	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-	entry->amount = value;
+	DB( g_print(" memo: '%s'\n", entry->memo) );
 
 	//free any previous string
 	if(	entry->info )
@@ -680,23 +684,19 @@ gint type, active;
 	{
 		entry->info = g_strdup(txt);
 	}
+	DB( g_print(" info: '%s'\n", entry->info) );
 
 	entry->paymode  = paymode_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
 	//entry->kcat     = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_cat));
 	entry->kcat     = ui_cat_entry_popover_get_key_add_new(GTK_BOX(data->PO_cat)); 
 	//entry->kpay     = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_pay));
 	entry->kpay     = ui_pay_entry_popover_get_key_add_new(GTK_BOX(data->PO_pay));
-	//entry->kacc     = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
-	entry->kacc     = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_acc));
-	//entry->kxferacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_accto));
-	entry->kxferacc = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_accto));
+	DB( g_print(" paymode: %d\n", entry->paymode) );
+	DB( g_print(" cat: %d\n", entry->kcat) );
+	DB( g_print(" pay: %d\n", entry->kpay) );
 
-	DB( g_print(" - acc: '%d'\n", entry->kacc) );
-
-	
-	/* tags */
 	txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
-	DB( g_print(" - tags: '%s'\n", txt) );
+	DB( g_print(" tags: '%s'\n", txt) );
 	g_free(entry->tags);
 	entry->tags = tags_parse(txt);
 
@@ -705,18 +705,16 @@ gint type, active;
 
 	// consistency checks
 
-	
-	/* for internal transfer add, amount must be expense */
-	// #617936
-	/*
-	if( entry->paymode == PAYMODE_INTXFER && data->action == OPERATION_EDIT_ADD )
+	//#617936/#1988594 ensure amount sign
+	if( data->action == TXN_DLG_ACTION_ADD )
 	{
-		if( entry->amount > 0 )
-			entry->amount *= -1;
+		entry->amount = ABS(entry->amount);
+		if( (type == TXN_TYPE_EXPENSE) || (type == TXN_TYPE_INTXFER) )
+		{
+			entry->amount = -entry->amount;
+		}
 	}
-	*/
 
-	
 	//#1615245: moved here, after get combo entry key
 	//if( entry->paymode != PAYMODE_INTXFER )
 	if( !(entry->flags & OF_INTXFER) )
@@ -729,7 +727,7 @@ gint type, active;
 
 	/* flags */
 	//entry->flags = 0;
-	entry->flags &= ~(OF_SPLIT);	//(split is set in hb_transaction)
+	entry->flags &= ~(OF_SPLIT|OF_CHEQ2);	//remove existing flags
 
 	//1859117: keep the split flag
 	if( da_splits_length (entry->splits) > 0 )
@@ -745,7 +743,7 @@ gint type, active;
 	if(active == 1) entry->flags |= OF_CHEQ2;
 
 	//active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_amount));
-	//we keep this in cas the user want to force the type
+	//we keep this in case the user want to force the type
 	da_transaction_set_flag(entry);
 
 }
@@ -867,7 +865,8 @@ Account *acc;
 						NULL,
 						_("Do you want to break the internal transfer?\n\n"
 						  "Proceeding will delete the target transaction."),
-						_("_Break")
+						_("_Break"),
+						TRUE
 					);
 	
 				if(break_result == GTK_RESPONSE_OK)
@@ -912,7 +911,6 @@ Account *acc;
 	gtk_widget_destroy (dialog);
 
 	DB( g_print("[ui-transaction] end external edit (from out)\n") );
-
 	
 	return result;
 }
@@ -1278,6 +1276,20 @@ struct WinGeometry *wg;
 }
 
 
+//#1681532 free in destroy event
+static void deftransaction_cb_destroy(GtkWidget *widget, gpointer user_data)
+{
+struct deftransaction_data *data;
+
+	DB( g_print("\n[ui-transaction] destroy cb\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print(" free data\n") );
+	g_free(data);
+}
+
+
 //note: this is called from external usage
 void deftransaction_dispose(GtkWidget *widget, gpointer user_data)
 {
@@ -1292,8 +1304,9 @@ struct deftransaction_data *data;
 		g_source_remove(data->evtsrcid);
 	
 	deftransaction_getgeometry(data->dialog, NULL, data);
-	
-	g_free(data);
+
+	//#1681532 don't free here
+	//g_free(data);
 }
 
 
@@ -1354,19 +1367,16 @@ gint row;
 			title = _("Add transaction");
 			if(type == TXN_DLG_TYPE_TPL) { title = _("Add template"); } 
 			else if(type == TXN_DLG_TYPE_SCH) { title = _("Post scheduled"); }
-			gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_OPE_ADD);
 			break;
 		case TXN_DLG_ACTION_INHERIT:
 			title = _("Inherit transaction");
 			if(type == TXN_DLG_TYPE_TPL)
 				title = _("Inherit template");
-			gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_OPE_HERIT);
 			break;
 		case TXN_DLG_ACTION_EDIT:
 			title = _("Edit transaction");
 			if(type == TXN_DLG_TYPE_TPL)
 				title = _("Edit template");
-			gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_OPE_EDIT);
 			break;
 	}
 
@@ -1627,7 +1637,6 @@ gint row;
 	data->LB_msgadded = label;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 3, 1);
 
-	
 	//setup, init and show window
 	deftransaction_setup(data);
 
@@ -1636,6 +1645,8 @@ gint row;
 
 	//connect all our signals
 	//g_signal_connect (dialog, "configure-event", G_CALLBACK (deftransaction_getgeometry), (gpointer)data);
+	//#1681532
+	g_signal_connect (dialog, "destroy", G_CALLBACK (deftransaction_cb_destroy), NULL);
 
 	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (deftransaction_cb_type_toggled), NULL);
 
